@@ -24,7 +24,6 @@
 #include "archivemailagentsettings.h"
 #include <AkonadiCore/ServerManager>
 
-#include <KLocalizedString>
 #include <MailCommon/MailKernel>
 #include <kdbusconnectionpool.h>
 #include <Monitor>
@@ -50,6 +49,7 @@ ArchiveMailAgent::ArchiveMailAgent(const QString &id)
     connect(mArchiveManager, &ArchiveMailManager::needUpdateConfigDialogBox, this, &ArchiveMailAgent::needUpdateConfigDialogBox);
 
     Akonadi::Monitor *collectionMonitor = new Akonadi::Monitor(this);
+    collectionMonitor->setObjectName(QStringLiteral("ArchiveMailCollectionMonitor"));
     collectionMonitor->fetchCollection(true);
     collectionMonitor->ignoreSession(Akonadi::Session::defaultSession());
     collectionMonitor->collectionFetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
