@@ -72,7 +72,7 @@ void ArchiveMailManager::load()
         ArchiveMailInfo *info = new ArchiveMailInfo(group);
 
         if (ArchiveMailAgentUtil::needToArchive(info)) {
-            Q_FOREACH (ArchiveMailInfo *oldInfo, mListArchiveInfo) {
+            for (ArchiveMailInfo *oldInfo : qAsConst(mListArchiveInfo)) {
                 if (oldInfo->saveCollectionId() == info->saveCollectionId()) {
                     //already in jobscheduler
                     delete info;
@@ -83,7 +83,7 @@ void ArchiveMailManager::load()
             if (info) {
                 //Store task started
                 mListArchiveInfo.append(info);
-                ScheduledArchiveTask *task = new ScheduledArchiveTask(this, info, Akonadi::Collection(info->saveCollectionId()), /*immediate*/false);
+                ScheduledArchiveTask *task = new ScheduledArchiveTask(this, info, Akonadi::Collection(info->saveCollectionId()), /*immediate*/ false);
                 mArchiveMailKernel->jobScheduler()->registerTask(task);
             }
         } else {
@@ -105,7 +105,7 @@ void ArchiveMailManager::removeCollectionId(Akonadi::Collection::Id id)
         group.deleteGroup();
         mConfig->sync();
         mConfig->reparseConfiguration();
-        Q_FOREACH (ArchiveMailInfo *info, mListArchiveInfo) {
+        foreach (ArchiveMailInfo *info, mListArchiveInfo) { //Don't port to for(...:...)
             if (info->saveCollectionId() == id) {
                 mListArchiveInfo.removeAll(info);
             }
@@ -166,7 +166,7 @@ QString ArchiveMailManager::printCurrentListInfo()
     if (mListArchiveInfo.isEmpty()) {
         infoStr = QStringLiteral("No archive in queue");
     } else {
-        Q_FOREACH (ArchiveMailInfo *info, mListArchiveInfo) {
+        for (ArchiveMailInfo *info : qAsConst(mListArchiveInfo)) {
             if (!infoStr.isEmpty()) {
                 infoStr += QLatin1Char('\n');
             }
@@ -211,4 +211,3 @@ void ArchiveMailManager::archiveFolder(const QString &path, Akonadi::Collection:
     slotArchiveNow(info);
     delete info;
 }
-
