@@ -34,7 +34,7 @@ public:
     ArchiveMailInfo *info() const;
 
 private:
-    ArchiveMailInfo *mInfo;
+    ArchiveMailInfo *mInfo = nullptr;
 };
 
 class ArchiveMailWidget : public QWidget
@@ -65,17 +65,16 @@ private:
     bool verifyExistingArchive(ArchiveMailInfo *info) const;
     void updateDiffDate(ArchiveMailItem *item, ArchiveMailInfo *info);
 
-private:
     void slotRemoveItem();
     void slotModifyItem();
     void slotAddItem();
     void updateButtons();
     void slotOpenFolder();
-    void customContextMenuRequested(const QPoint &);
+    void slotCustomContextMenuRequested(const QPoint &);
     void slotArchiveNow();
     void slotItemChanged(QTreeWidgetItem *item, int);
-    bool mChanged;
-    Ui::ArchiveMailWidget *mWidget;
+    bool mChanged = false;
+    Ui::ArchiveMailWidget *mWidget = nullptr;
 };
 
 #endif // ARCHIVEMAILWIDGET_H
