@@ -33,6 +33,7 @@
 #include <Kdelibs4ConfigMigrator>
 #include <AkonadiCore/Session>
 #include <AkonadiCore/CollectionFetchScope>
+#include <AkonadiCore/ServerManager>
 
 #include <QPointer>
 #include "followupreminderagent_debug.h"
@@ -47,7 +48,12 @@ FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
 
     new FollowUpReminderAgentAdaptor(this);
     KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/FollowUpReminder"), this, QDBusConnection::ExportAdaptors);
-    KDBusConnectionPool::threadConnection().registerService(QStringLiteral("org.freedesktop.Akonadi.FollowUpReminder"));
+    QString service = QStringLiteral("org.freedesktop.Akonadi.FollowUpReminder");
+    if (Akonadi::ServerManager::hasInstanceIdentifier()) {
+        service += QLatin1Char('.') + Akonadi::ServerManager::instanceIdentifier();
+    }
+
+    KDBusConnectionPool::threadConnection().registerService(service);
     mManager = new FollowUpReminderManager(this);
     setNeedsNetwork(true);
 
@@ -100,11 +106,7 @@ void FollowUpReminderAgent::showConfigureDialog(qlonglong windowId)
     QPointer<FollowUpReminderInfoDialog> dialog = new FollowUpReminderInfoDialog();
     dialog->load();
     if (windowId) {
-#ifndef Q_OS_WIN
         KWindowSystem::setMainWindow(dialog, windowId);
-#else
-        KWindowSystem::setMainWindow(dialog, (HWND)windowId);
-#endif
     }
     if (dialog->exec()) {
         const QList<qint32> lstRemoveItem = dialog->listRemoveId();
@@ -147,4 +149,3 @@ QString FollowUpReminderAgent::printDebugInfo()
 }
 
 AKONADI_AGENT_MAIN(FollowUpReminderAgent)
-
