@@ -39,7 +39,7 @@ public:
     FollowUpReminder::FollowUpReminderInfo *info() const;
 
 private:
-    FollowUpReminder::FollowUpReminderInfo *mInfo;
+    FollowUpReminder::FollowUpReminderInfo *mInfo = nullptr;
 };
 
 class FollowUpReminderInfoWidget : public QWidget
@@ -61,7 +61,7 @@ public:
     QList<qint32> listRemoveId() const;
 
 private:
-    void customContextMenuRequested(const QPoint &pos);
+    void slotCustomContextMenuRequested(const QPoint &pos);
     void createOrUpdateItem(FollowUpReminder::FollowUpReminderInfo *info, FollowUpReminderInfoItem *item = nullptr);
     void removeItem(const QList<QTreeWidgetItem *> &mailItem);
     void openShowMessage(Akonadi::Item::Id id);
@@ -79,8 +79,8 @@ private:
         AnswerMessageId
     };
     QList<qint32> mListRemoveId;
-    QTreeWidget *mTreeWidget;
-    bool mChanged;
+    QTreeWidget *mTreeWidget = nullptr;
+    bool mChanged = false;
 };
 
 #endif // FOLLOWUPREMINDERINFOWIDGET_H
