@@ -28,6 +28,8 @@
 #include <AkonadiCore/itemmodifyjob.h>
 #include <AkonadiCore/itemmovejob.h>
 #include <AkonadiCore/itemdeletejob.h>
+#include <AkonadiCore/EntityTreeModel>
+#include <AkonadiCore/EntityMimeTypeFilterModel>
 #include <Akonadi/KMime/MessageParts>
 #include <kconfig.h>
 #include <kconfiggroup.h>
@@ -40,9 +42,7 @@
 #include <MailCommon/FilterImporterExporter>
 #include <MailCommon/FilterLog>
 #include <MailCommon/MailFilter>
-#include <MailCommon/MailUtil>
-
-#include <QTimer>
+#include <MailCommon/MailKernel>
 
 // other headers
 #include <algorithm>
@@ -83,9 +83,10 @@ public:
     QMap<QString, SearchRule::RequiredPart> mRequiredParts;
     SearchRule::RequiredPart mRequiredPartsBasedOnAll;
     QPixmap pixmapNotification;
-    bool mInboundFiltersExist;
-    int mTotalProgressCount;
-    int mCurrentProgressCount;
+    bool mInboundFiltersExist = false;
+    bool mAllFoldersFiltersExist = false;
+    int mTotalProgressCount = 0;
+    int mCurrentProgressCount = 0;
 };
 
 void FilterManager::Private::slotItemsFetchedForFilter(const Akonadi::Item::List &items)
@@ -345,8 +346,17 @@ void FilterManager::readConfig()
         }
     }
     // check if at least one filter is to be applied on inbound mail
-    d->mInboundFiltersExist = std::find_if(d->mFilters.constBegin(), d->mFilters.constEnd(),
-                                           std::mem_fn(&MailCommon::MailFilter::applyOnInbound)) != d->mFilters.constEnd();
+
+    for (auto i = d->mFilters.cbegin(), e = d->mFilters.cend();
+         i != e && (!d->mInboundFiltersExist || !d->mAllFoldersFiltersExist);
+         ++i) {
+        if ((*i)->applyOnInbound()) {
+            d->mInboundFiltersExist = true;
+        }
+        if ((*i)->applyOnAllFoldersInbound()) {
+            d->mAllFoldersFiltersExist = true;
+        }
+    }
 
     Q_EMIT filterListUpdated();
 }
@@ -384,7 +394,9 @@ void FilterManager::filter(const Akonadi::Item &item, FilterManager::FilterSet s
     }
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-    connect(job, SIGNAL(result(KJob *)), SLOT(itemFetchJobForFilterDone(KJob *)));
+    connect(job, &Akonadi::ItemFetchJob::result, this, [this](KJob *job) {
+        d->itemFetchJobForFilterDone(job);
+    });
 }
 
 void FilterManager::filter(const Akonadi::Item &item, const QString &filterId, const QString &resourceId)
@@ -403,7 +415,9 @@ void FilterManager::filter(const Akonadi::Item &item, const QString &filterId, c
 
     job->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
 
-    connect(job, SIGNAL(result(KJob *)), SLOT(itemFetchJobForFilterDone(KJob *)));
+    connect(job, &Akonadi::ItemFetchJob::result, this, [this](KJob *job) {
+        d->itemFetchJobForFilterDone(job);
+    });
 }
 
 bool FilterManager::process(const Akonadi::Item &item, bool needsFullPayload, const MailFilter *filter)
@@ -421,14 +435,14 @@ bool FilterManager::process(const Akonadi::Item &item, bool needsFullPayload, co
         return false;
     }
 
-    bool stopIt = false;
-    bool applyOnOutbound = false;
     if (d->isMatching(item, filter)) {
         // do the actual filtering stuff
         d->beginFiltering(item);
 
         ItemContext context(item, needsFullPayload);
 
+        bool stopIt = false;
+        bool applyOnOutbound = false;
         if (filter->execActions(context, stopIt, applyOnOutbound) == MailCommon::MailFilter::CriticalError) {
             return false;
         }
@@ -448,11 +462,15 @@ bool FilterManager::processContextItem(ItemContext context)
     const KMime::Message::Ptr msg = context.item().payload<KMime::Message::Ptr>();
     msg->assemble();
 
-    const bool itemCanDelete = (MailCommon::Util::updatedCollection(context.item().parentCollection()).rights() & Akonadi::Collection::CanDeleteItem);
+    auto col = Akonadi::EntityTreeModel::updatedCollection(MailCommon::Kernel::self()->kernelIf()->collectionModel(),
+                                                           context.item().parentCollection());
+    const bool itemCanDelete = (col.rights() & Akonadi::Collection::CanDeleteItem);
     if (context.deleteItem()) {
         if (itemCanDelete) {
             Akonadi::ItemDeleteJob *deleteJob = new Akonadi::ItemDeleteJob(context.item(), this);
-            connect(deleteJob, SIGNAL(result(KJob *)), SLOT(deleteJobResult(KJob *)));
+            connect(deleteJob, &Akonadi::ItemDeleteJob::result, this, [this](KJob *job) {
+                d->deleteJobResult(job);
+            });
         } else {
             return false;
         }
@@ -460,7 +478,9 @@ bool FilterManager::processContextItem(ItemContext context)
         if (context.moveTargetCollection().isValid() && context.item().storageCollectionId() != context.moveTargetCollection().id()) {
             if (itemCanDelete) {
                 Akonadi::ItemMoveJob *moveJob = new Akonadi::ItemMoveJob(context.item(), context.moveTargetCollection(), this);
-                connect(moveJob, SIGNAL(result(KJob *)), SLOT(moveJobResult(KJob *)));
+                connect(moveJob, &Akonadi::ItemMoveJob::result, this, [this](KJob *job) {
+                    d->moveJobResult(job);
+                });
             } else {
                 return false;
             }
@@ -477,7 +497,9 @@ bool FilterManager::processContextItem(ItemContext context)
             //The below is a safety check to ignore modifying payloads if it was not requested,
             //as in that case we might change the payload to an invalid one
             modifyJob->setIgnorePayload(!context.needsFullPayload());
-            connect(modifyJob, SIGNAL(result(KJob *)), SLOT(modifyJobResult(KJob *)));
+            connect(modifyJob, &Akonadi::ItemModifyJob::result, this, [this](KJob *job) {
+                d->modifyJobResult(job);
+            });
         }
     }
 
@@ -512,9 +534,10 @@ bool FilterManager::process(const QList< MailFilter * > &mailFilters, const Akon
             const bool outboundOk = ((set & Outbound) && (*it)->applyOnOutbound());
             const bool beforeOutboundOk = ((set & BeforeOutbound) && (*it)->applyBeforeOutbound());
             const bool explicitOk = ((set & Explicit) && (*it)->applyOnExplicit());
-            const bool accountOk = (!account || (account && (*it)->applyOnAccount(accountId)));
+            const bool allFoldersOk = ((set & AllFolders) && (*it)->applyOnAllFoldersInbound());
+            const bool accountOk = (!account || (*it)->applyOnAccount(accountId));
 
-            if ((inboundOk && accountOk) || outboundOk || beforeOutboundOk || explicitOk) {
+            if ((inboundOk && accountOk) || (allFoldersOk && accountOk) || outboundOk || beforeOutboundOk || explicitOk) {
                 // filter is applicable
 
                 if (d->isMatching(context.item(), *it)) {
@@ -572,7 +595,6 @@ MailCommon::SearchRule::RequiredPart FilterManager::requiredPart(const QString &
     return d->mRequiredParts.contains(id) ? d->mRequiredParts[id] : SearchRule::Envelope;
 }
 
-#ifndef NDEBUG
 void FilterManager::dump() const
 {
     for (const MailCommon::MailFilter *filter : qAsConst(d->mFilters)) {
@@ -580,9 +602,7 @@ void FilterManager::dump() const
     }
 }
 
-#endif
-
-void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMessages, SearchRule::RequiredPart requiredPart, const QStringList &listFilters)
+void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMessages, SearchRule::RequiredPart requiredPart, const QStringList &listFilters, FilterSet filterSet)
 {
     Q_EMIT progressMessage(i18n("Filtering messages"));
     d->mTotalProgressCount = selectedMessages.size();
@@ -599,12 +619,15 @@ void FilterManager::applySpecificFilters(const Akonadi::Item::List &selectedMess
 
     itemFetchJob->fetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     itemFetchJob->setProperty("listFilters", QVariant::fromValue(listFilters));
+    itemFetchJob->setProperty("filterSet", QVariant::fromValue(static_cast<int>(filterSet)));
     itemFetchJob->setProperty("needsFullPayload", requiredPart != SearchRule::Envelope);
 
-    connect(itemFetchJob, SIGNAL(itemsReceived(Akonadi::Item::List)),
-            this, SLOT(slotItemsFetchedForFilter(Akonadi::Item::List)));
-    connect(itemFetchJob, SIGNAL(result(KJob *)),
-            SLOT(itemsFetchJobForFilterDone(KJob *)));
+    connect(itemFetchJob, &Akonadi::ItemFetchJob::itemsReceived, this, [this](const Akonadi::Item::List &lst) {
+        d->slotItemsFetchedForFilter(lst);
+    });
+    connect(itemFetchJob, &Akonadi::ItemFetchJob::result, this, [this](KJob *job) {
+        d->itemsFetchJobForFilterDone(job);
+    });
 }
 
 void FilterManager::applyFilters(const Akonadi::Item::List &selectedMessages, FilterSet filterSet)
@@ -627,10 +650,17 @@ void FilterManager::applyFilters(const Akonadi::Item::List &selectedMessages, Fi
     itemFetchJob->setProperty("filterSet", QVariant::fromValue(static_cast<int>(filterSet)));
     itemFetchJob->setProperty("needsFullPayload", requiredParts != SearchRule::Envelope);
 
-    connect(itemFetchJob, SIGNAL(itemsReceived(Akonadi::Item::List)),
-            this, SLOT(slotItemsFetchedForFilter(Akonadi::Item::List)));
-    connect(itemFetchJob, SIGNAL(result(KJob *)),
-            SLOT(itemsFetchJobForFilterDone(KJob *)));
+    connect(itemFetchJob, &Akonadi::ItemFetchJob::itemsReceived, this, [this](const Akonadi::Item::List &lst) {
+        d->slotItemsFetchedForFilter(lst);
+    });
+    connect(itemFetchJob, &Akonadi::ItemFetchJob::result, this, [this](KJob *job) {
+        d->itemsFetchJobForFilterDone(job);
+    });
+}
+
+bool FilterManager::hasAllFoldersFilter() const
+{
+    return d->mAllFoldersFiltersExist;
 }
 
 #include "moc_filtermanager.cpp"
