@@ -48,15 +48,18 @@
 #include <AttributeFactory>
 #include <KConfigGroup>
 
-#include <QVector>
 #include <QTimer>
 #include <KSharedConfig>
 
 #include <kdelibs4configmigrator.h>
 
-static bool isFilterableCollection(const Akonadi::Collection &collection)
+bool MailFilterAgent::isFilterableCollection(const Akonadi::Collection &collection) const
 {
-    return MailCommon::Kernel::folderIsInbox(collection);
+    if (!collection.contentMimeTypes().contains(KMime::Message::mimeType())) {
+        return false;
+    }
+
+    return m_filterManager->hasAllFoldersFilter() || MailCommon::Kernel::folderIsInbox(collection);
 
     //TODO: check got filter attribute here
 }
@@ -80,14 +83,15 @@ MailFilterAgent::MailFilterAgent(const QString &id)
     connect(m_filterManager, &FilterManager::progressMessage, this, &MailFilterAgent::emitProgressMessage);
 
     Akonadi::Monitor *collectionMonitor = new Akonadi::Monitor(this);
+    collectionMonitor->setObjectName(QStringLiteral("MailFilterCollectionMonitor"));
     collectionMonitor->fetchCollection(true);
     collectionMonitor->ignoreSession(Akonadi::Session::defaultSession());
     collectionMonitor->collectionFetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
     collectionMonitor->setMimeTypeMonitored(KMime::Message::mimeType());
 
     connect(collectionMonitor, &Akonadi::Monitor::collectionAdded, this, &MailFilterAgent::mailCollectionAdded);
-    connect(collectionMonitor, SIGNAL(collectionChanged(Akonadi::Collection)),
-            this, SLOT(mailCollectionChanged(Akonadi::Collection)));
+    connect(collectionMonitor, QOverload<const Akonadi::Collection &>::of(&Akonadi::Monitor::collectionChanged),
+            this, &MailFilterAgent::mailCollectionChanged);
 
     connect(collectionMonitor, &Akonadi::Monitor::collectionRemoved, this, &MailFilterAgent::mailCollectionRemoved);
     connect(Akonadi::AgentManager::self(), &Akonadi::AgentManager::instanceRemoved, this, &MailFilterAgent::slotInstanceRemoved);
@@ -126,9 +130,12 @@ MailFilterAgent::MailFilterAgent(const QString &id)
 
     mProgressCounter = 0;
     mProgressTimer = new QTimer(this);
-    connect(mProgressTimer, SIGNAL(timeout()), this, SLOT(emitProgress()));
+    connect(mProgressTimer, &QTimer::timeout, this, [this]() {
+        emitProgress();
+    });
 
     itemMonitor = new Akonadi::Monitor(this);
+    itemMonitor->setObjectName(QStringLiteral("MailFilterItemMonitor"));
     itemMonitor->itemFetchScope().setFetchRemoteIdentification(true);
     itemMonitor->itemFetchScope().setAncestorRetrieval(Akonadi::ItemFetchScope::Parent);
     connect(itemMonitor, &Akonadi::Monitor::itemChanged, this, &MailFilterAgent::slotItemChanged);
@@ -148,9 +155,12 @@ void MailFilterAgent::initializeCollections()
 {
     m_filterManager->readConfig();
 
-    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(), Akonadi::CollectionFetchJob::Recursive, this);
-    job->fetchScope().setContentMimeTypes(QStringList() << KMime::Message::mimeType());
-    connect(job, &Akonadi::CollectionFetchJob::result, this, &MailFilterAgent::initialCollectionFetchingDone);
+    Akonadi::CollectionFetchJob *job = new Akonadi::CollectionFetchJob(Akonadi::Collection::root(),
+                                                                       Akonadi::CollectionFetchJob::Recursive,
+                                                                       this);
+    job->fetchScope().setContentMimeTypes({ KMime::Message::mimeType() });
+    connect(job, &Akonadi::CollectionFetchJob::result,
+            this, &MailFilterAgent::initialCollectionFetchingDone);
 }
 
 void MailFilterAgent::initialCollectionFetchingDone(KJob *job)
@@ -160,23 +170,20 @@ void MailFilterAgent::initialCollectionFetchingDone(KJob *job)
         return; //TODO: proper error handling
     }
 
-    Akonadi::CollectionFetchJob *fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
+    const auto fetchJob = qobject_cast<Akonadi::CollectionFetchJob *>(job);
 
-    const QMap<QString, Akonadi::Collection::Id> pop3ResourceMap = MailCommon::Kernel::pop3ResourceTargetCollection();
+    const auto pop3ResourceMap = MailCommon::Kernel::pop3ResourceTargetCollection();
 
-    const Akonadi::Collection::List lstCols = fetchJob->collections();
+    const auto lstCols = fetchJob->collections();
     for (const Akonadi::Collection &collection : lstCols) {
         if (isFilterableCollection(collection)) {
             changeRecorder()->setCollectionMonitored(collection, true);
         } else {
-            QMap<QString, Akonadi::Collection::Id>::const_iterator i = pop3ResourceMap.constBegin();
-            const QMap<QString, Akonadi::Collection::Id>::const_iterator end = pop3ResourceMap.constEnd();
-            while (i != end) {
-                if (collection.id() == i.value()) {
+            for (auto pop3ColId : pop3ResourceMap) {
+                if (collection.id() == pop3ColId) {
                     changeRecorder()->setCollectionMonitored(collection, true);
                     break;
                 }
-                ++i;
             }
         }
     }
@@ -309,6 +316,22 @@ void MailFilterAgent::filterItems(const QList< qint64 > &itemIds, int filterSet)
     m_filterManager->applyFilters(items, static_cast<FilterManager::FilterSet>(filterSet));
 }
 
+void MailFilterAgent::filterCollections(const QList<qint64> &collections, int filterSet)
+{
+    for (qint64 id: collections) {
+        auto ifj = new Akonadi::ItemFetchJob{
+            Akonadi::Collection{
+                id
+            }, this
+        };
+        ifj->setDeliveryOption(Akonadi::ItemFetchJob::EmitItemsInBatches);
+        connect(ifj, &Akonadi::ItemFetchJob::itemsReceived,
+                this, [=](const Akonadi::Item::List &items) {
+            m_filterManager->applyFilters(items, static_cast<FilterManager::FilterSet>(filterSet));
+        });
+    }
+}
+
 void MailFilterAgent::applySpecificFilters(const QList< qint64 > &itemIds, int requires, const QStringList &listFilters)
 {
     Akonadi::Item::List items;
@@ -320,6 +343,25 @@ void MailFilterAgent::applySpecificFilters(const QList< qint64 > &itemIds, int r
     m_filterManager->applySpecificFilters(items, static_cast<MailCommon::SearchRule::RequiredPart>(requires), listFilters);
 }
 
+void MailFilterAgent::applySpecificFiltersOnCollections(const QList<qint64> &colIds, const QStringList &listFilters, int filterSet)
+{
+    // TODO: Actually calculate this based on the listFilters' requirements
+    const auto requires = MailCommon::SearchRule::CompleteMessage;
+
+    for (qint64 id : colIds) {
+        auto ifj = new Akonadi::ItemFetchJob{
+            Akonadi::Collection{
+                id
+            }, this
+        };
+        ifj->setDeliveryOption(Akonadi::ItemFetchJob::EmitItemsInBatches);
+        connect(ifj, &Akonadi::ItemFetchJob::itemsReceived,
+                this, [=](const Akonadi::Item::List &items) {
+            m_filterManager->applySpecificFilters(items, requires, listFilters, static_cast<FilterManager::FilterSet>(filterSet));
+        });
+    }
+}
+
 void MailFilterAgent::filterItem(qint64 item, int filterSet, const QString &resourceId)
 {
     m_filterManager->filter(Akonadi::Item(item), static_cast<FilterManager::FilterSet>(filterSet), resourceId);
