@@ -50,7 +50,9 @@ public:
 
     void filterItem(qint64 item, int filterSet, const QString &resourceId);
     void filter(qint64 item, const QString &filterIdentifier, const QString &resourceId);
+    void filterCollections(const QList<qint64> &collections, int filterSet);
     void applySpecificFilters(const QList< qint64 > &itemIds, int requires, const QStringList &listFilters);
+    void applySpecificFiltersOnCollections(const QList<qint64> &colIds, const QStringList &listFilters, int filterSet);
 
     void reload();
 
@@ -80,13 +82,15 @@ public Q_SLOTS:
     void configure(WId windowId) override;
 
 private:
-    FilterManager *m_filterManager;
+    bool isFilterableCollection(const Akonadi::Collection &collection) const;
 
-    FilterLogDialog *m_filterLogDialog;
-    QTimer *mProgressTimer;
-    DummyKernel *mMailFilterKernel;
+    FilterManager *m_filterManager = nullptr;
+
+    FilterLogDialog *m_filterLogDialog = nullptr;
+    QTimer *mProgressTimer = nullptr;
+    DummyKernel *mMailFilterKernel = nullptr;
     int mProgressCounter;
-    Akonadi::Monitor *itemMonitor;
+    Akonadi::Monitor *itemMonitor = nullptr;
 
     void filterItem(const Akonadi::Item &item, const Akonadi::Collection &collection);
 };
