@@ -27,9 +27,8 @@
 #include <KHelpMenu>
 #include <QMenu>
 #include <kaboutdata.h>
-#include <KMessageBox>
 #include <QIcon>
-
+#include <QDialogButtonBox>
 #include <QApplication>
 
 SendLaterConfigureDialog::SendLaterConfigureDialog(QWidget *parent)
@@ -37,9 +36,8 @@ SendLaterConfigureDialog::SendLaterConfigureDialog(QWidget *parent)
 {
     setWindowTitle(i18n("Configure"));
     setWindowIcon(QIcon::fromTheme(QStringLiteral("kmail")));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help);
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    setLayout(mainLayout);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Help, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
