@@ -40,7 +40,7 @@ public:
     SendLater::SendLaterInfo *info() const;
 
 private:
-    SendLater::SendLaterInfo *mInfo;
+    SendLater::SendLaterInfo *mInfo = nullptr;
 };
 
 class SendLaterWidget : public QWidget
@@ -71,13 +71,13 @@ private:
     void slotRemoveItem();
     void slotModifyItem();
     void updateButtons();
-    void customContextMenuRequested(const QPoint &);
+    void slotCustomContextMenuRequested(const QPoint &);
     void slotSendNow();
     void createOrUpdateItem(SendLater::SendLaterInfo *info, SendLaterItem *item = nullptr);
     void load();
     QList<Akonadi::Item::Id> mListMessagesToRemove;
     bool mChanged;
-    Ui::SendLaterConfigureWidget *mWidget;
+    Ui::SendLaterConfigureWidget *mWidget = nullptr;
 };
 
 #endif // SENDLATERCONFIGUREWIDGET_H
