@@ -22,7 +22,6 @@
 
 #include "MessageComposer/AkonadiSender"
 #include <MessageComposer/Util>
-#include "messagecore/messagehelpers.h"
 #include <MessageCore/StringUtil>
 
 #include <mailtransportakonadi/transportattribute.h>
@@ -40,9 +39,9 @@
 #include "sendlateragent_debug.h"
 
 SendLaterJob::SendLaterJob(SendLaterManager *manager, SendLater::SendLaterInfo *info, QObject *parent)
-    : QObject(parent),
-      mManager(manager),
-      mInfo(info)
+    : QObject(parent)
+    , mManager(manager)
+    , mInfo(info)
 {
     qCDebug(SENDLATERAGENT_LOG) << " SendLaterJob::SendLaterJob" << this;
 }
@@ -104,11 +103,12 @@ void SendLaterJob::slotJobFinished(KJob *job)
     }
 
     if (mItem.isValid()) {
-        const KMime::Message::Ptr msg = MessageCore::Util::message(mItem);
+        const KMime::Message::Ptr msg = MessageComposer::Util::message(mItem);
         if (!msg) {
             sendError(i18n("Message is not a real message"), SendLaterManager::CanNotFetchItem);
             return;
         }
+        //TODO verify encryption + signed
         updateAndCleanMessageBeforeSending(msg);
 
         if (!mManager->sender()->send(msg, MessageComposer::MessageSender::SendImmediate)) {
@@ -165,4 +165,3 @@ void SendLaterJob::sendError(const QString &error, SendLaterManager::ErrorType t
     mManager->sendError(mInfo, type);
     deleteLater();
 }
-
