@@ -36,10 +36,10 @@
 #include <QTimer>
 
 SendLaterManager::SendLaterManager(QObject *parent)
-    : QObject(parent),
-      mCurrentInfo(nullptr),
-      mCurrentJob(nullptr),
-      mSender(new MessageComposer::AkonadiSender)
+    : QObject(parent)
+    , mCurrentInfo(nullptr)
+    , mCurrentJob(nullptr)
+    , mSender(new MessageComposer::AkonadiSender)
 {
     mConfig = KSharedConfig::openConfig();
     mTimer = new QTimer(this);
@@ -123,7 +123,7 @@ void SendLaterManager::stopTimer()
 
 SendLater::SendLaterInfo *SendLaterManager::searchInfo(Akonadi::Item::Id id)
 {
-    Q_FOREACH (SendLater::SendLaterInfo *info, mListSendLaterInfo) {
+    for (SendLater::SendLaterInfo *info : qAsConst(mListSendLaterInfo)) {
         if (info->itemId() == id) {
             return info;
         }
@@ -233,7 +233,7 @@ QString SendLaterManager::printDebugInfo()
     if (mListSendLaterInfo.isEmpty()) {
         infoStr = QStringLiteral("No mail");
     } else {
-        Q_FOREACH (SendLater::SendLaterInfo *info, mListSendLaterInfo) {
+        for (SendLater::SendLaterInfo *info : qAsConst(mListSendLaterInfo)) {
             if (!infoStr.isEmpty()) {
                 infoStr += QLatin1Char('\n');
             }
@@ -258,4 +258,3 @@ MessageComposer::AkonadiSender *SendLaterManager::sender() const
 {
     return mSender;
 }
-
