@@ -18,8 +18,6 @@
 */
 
 #include <QApplication>
-#include <KAboutData>
-#include <KLocalizedString>
 #include <QCommandLineParser>
 #include <QStandardPaths>
 #include "sendlaterdialog.h"
@@ -28,15 +26,10 @@ int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
     QStandardPaths::setTestModeEnabled(true);
-    KAboutData aboutData(QStringLiteral("sendlaterdialog_gui"), i18n("SendLaterDialog_Gui"), QStringLiteral("1.0"));
-    aboutData.setShortDescription(i18n("Test for autocreate sendlater dialog"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
     SendLater::SendLaterDialog *dialog = new SendLater::SendLaterDialog(nullptr);
     dialog->exec();
     delete dialog;
