@@ -35,7 +35,6 @@
 #include <QVBoxLayout>
 
 #include <KComboBox>
-#include <QDialog>
 #include <KLineEdit>
 #include <KEditListWidget>
 #include <KLocalizedString>
@@ -47,9 +46,6 @@ using namespace MailCommon;
 
 CollectionMailingListPage::CollectionMailingListPage(QWidget *parent)
     : CollectionPropertiesPage(parent)
-    , mGroupWidget(nullptr)
-    , mLastItem(0)
-    , changed(false)
 {
     setObjectName(QStringLiteral("KMail::CollectionMailingListPage"));
     setPageTitle(i18nc("@title:tab Mailing list settings for a folder.", "Mailing List"));
@@ -106,7 +102,7 @@ void CollectionMailingListPage::init(const Akonadi::Collection &col)
     mMLHandlerCombo->addItem(i18n("KMail"), MailingList::KMail);
     mMLHandlerCombo->addItem(i18n("Browser"), MailingList::Browser);
     groupLayout->addWidget(mMLHandlerCombo, 5, 1, 1, 2);
-    connect(mMLHandlerCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &CollectionMailingListPage::slotMLHandling);
+    connect(mMLHandlerCombo, QOverload<int>::of(&KComboBox::activated), this, &CollectionMailingListPage::slotMLHandling);
     label->setBuddy(mMLHandlerCombo);
 
     label = new QLabel(i18n("Address type:"), mGroupWidget);
@@ -132,17 +128,13 @@ void CollectionMailingListPage::init(const Akonadi::Collection &col)
     connect(mEditList, &KEditListWidget::changed, this, &CollectionMailingListPage::slotConfigChanged);
     groupLayout->addWidget(mEditList, 7, 0, 1, 4);
 
-    QStringList el;
-
     //Order is important because the activate handler and fillMLFromWidgets
     //depend on it
-    el << i18n("Post to List")
-       << i18n("Subscribe to List")
-       << i18n("Unsubscribe From List")
-       << i18n("List Archives")
-       << i18n("List Help");
+    const QStringList el {
+        i18n("Post to List"), i18n("Subscribe to List"), i18n("Unsubscribe From List"), i18n("List Archives"), i18n("List Help")
+    };
     mAddressCombo->addItems(el);
-    connect(mAddressCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &CollectionMailingListPage::slotAddressChanged);
+    connect(mAddressCombo, QOverload<int>::of(&KComboBox::activated), this, &CollectionMailingListPage::slotAddressChanged);
 
     topLayout->addWidget(mGroupWidget);
     mGroupWidget->setEnabled(false);
