@@ -48,6 +48,7 @@ using MailTransport::TransportManagementWidget;
 #include <QMenu>
 #include <KConfigGroup>
 #include <QLabel>
+#include <QProcess>
 
 QString AccountsPage::helpAnchor() const
 {
@@ -117,7 +118,7 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
                                 << i18n("On Manual Mail Checks")
                                 << i18n("On All Mail Checks"));
     glay->addWidget(mSendOnCheckCombo, 2, 1);
-    connect(mSendOnCheckCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
+    connect(mSendOnCheckCombo, QOverload<int>::of(&KComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
 
     // "default send method" combo:
     mSendMethodCombo = new KComboBox(group);
@@ -126,7 +127,7 @@ AccountsPageSendingTab::AccountsPageSendingTab(QWidget *parent)
                                << i18n("Send Now")
                                << i18n("Send Later"));
     glay->addWidget(mSendMethodCombo, 3, 1);
-    connect(mSendMethodCombo, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
+    connect(mSendMethodCombo, QOverload<int>::of(&KComboBox::activated), this, &AccountsPageSendingTab::slotEmitChanged);
 
     // labels:
     QLabel *l = new QLabel(i18n("Send &messages in outbox folder:"), group);
@@ -203,6 +204,11 @@ AccountsPageReceivingTab::AccountsPageReceivingTab(QWidget *parent)
 
     connect(mAccountsReceiving.mOtherNewMailActionsButton, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotEditNotifications);
     connect(mAccountsReceiving.customizeAccountOrder, &QAbstractButton::clicked, this, &AccountsPageReceivingTab::slotCustomizeAccountOrder);
+    mAccountsReceiving.mAccountsReceiving->disconnectAddAccountButton();
+    QMenu *accountMenu = new QMenu(this);
+    accountMenu->addAction(i18n("Add Mail Account..."), this, &AccountsPageReceivingTab::slotAddMailAccount);
+    accountMenu->addAction(i18n("Custom Account..."), this, &AccountsPageReceivingTab::slotAddCustomAccount);
+    mAccountsReceiving.mAccountsReceiving->addAccountButton()->setMenu(accountMenu);
 }
 
 AccountsPageReceivingTab::~AccountsPageReceivingTab()
@@ -211,10 +217,30 @@ AccountsPageReceivingTab::~AccountsPageReceivingTab()
     mRetrievalHash.clear();
 }
 
+void AccountsPageReceivingTab::slotAddCustomAccount()
+{
+    mAccountsReceiving.mAccountsReceiving->slotAddAccount();
+}
+
+void AccountsPageReceivingTab::slotAddMailAccount()
+{
+    const QStringList lst = {QStringLiteral("--type"), QStringLiteral("message/rfc822") };
+
+    const QString path = QStandardPaths::findExecutable(QStringLiteral("accountwizard"));
+    if (!QProcess::startDetached(path, lst)) {
+        KMessageBox::error(this, i18n("Could not start the account wizard. "
+                                      "Please make sure you have AccountWizard properly installed."),
+                           i18n("Unable to start account wizard"));
+    }
+}
+
 void AccountsPageReceivingTab::slotCustomizeAccountOrder()
 {
-    MailCommon::AccountConfigOrderDialog dlg(this);
-    dlg.exec();
+    if (KMKernel::self()) {
+        QPointer<MailCommon::AccountConfigOrderDialog> dlg = new MailCommon::AccountConfigOrderDialog(KMKernel::self()->mailCommonSettings(), this);
+        dlg->exec();
+        delete dlg;
+    }
 }
 
 void AccountsPageReceivingTab::slotShowMailCheckMenu(const QString &ident, const QPoint &pos)
