@@ -41,10 +41,10 @@ private:
     void doLoadOther() override;
 
 private:
-    QCheckBox *mConfirmSendCheck;
-    QCheckBox *mCheckSpellingBeforeSending;
-    KComboBox *mSendOnCheckCombo;
-    KComboBox *mSendMethodCombo;
+    QCheckBox *mConfirmSendCheck = nullptr;
+    QCheckBox *mCheckSpellingBeforeSending = nullptr;
+    KComboBox *mSendOnCheckCombo = nullptr;
+    KComboBox *mSendMethodCombo = nullptr;
 };
 
 class AccountsPageReceivingTab : public ConfigModuleTab
@@ -76,16 +76,18 @@ private:
         {
         }
 
-        bool IncludeInManualChecks;
-        bool OfflineOnShutdown;
-        bool CheckOnStartup;
+        bool IncludeInManualChecks = false;
+        bool OfflineOnShutdown = false;
+        bool CheckOnStartup = false;
     };
 
     QHash<QString, QSharedPointer<RetrievalOptions> > mRetrievalHash;
 
 private:
+    void slotAddCustomAccount();
+    void slotAddMailAccount();
     Ui_AccountsPageReceivingTab mAccountsReceiving;
-    OrgFreedesktopAkonadiNewMailNotifierInterface *mNewMailNotifierInterface;
+    OrgFreedesktopAkonadiNewMailNotifierInterface *mNewMailNotifierInterface = nullptr;
 };
 
 class KMAIL_EXPORT AccountsPage : public ConfigModuleWithTabs
