@@ -88,6 +88,13 @@ QString AppearancePage::helpAnchor() const
 AppearancePage::AppearancePage(QWidget *parent)
     : ConfigModuleWithTabs(parent)
 {
+    //
+    // "General" tab:
+    //
+    ReaderTab *readerTab = new ReaderTab();
+    addTab(readerTab, i18n("General"));
+    addConfig(MessageViewer::MessageViewerSettings::self(), readerTab);
+
     //
     // "Fonts" tab:
     //
@@ -112,19 +119,6 @@ AppearancePage::AppearancePage(QWidget *parent)
     HeadersTab *headersTab = new HeadersTab();
     addTab(headersTab, i18n("Message List"));
 
-    //
-    // "Reader window" tab:
-    //
-    ReaderTab *readerTab = new ReaderTab();
-    addTab(readerTab, i18n("Message Window"));
-    addConfig(MessageViewer::MessageViewerSettings::self(), readerTab);
-
-    //
-    // "System Tray" tab:
-    //
-    SystemTrayTab *systemTrayTab = new SystemTrayTab();
-    addTab(systemTrayTab, i18n("System Tray"));
-
     //
     // "Message Tag" tab:
     //
@@ -376,8 +370,8 @@ AppearancePageColorsTab::AppearancePageColorsTab(QWidget *parent)
     mCloseToQuotaThreshold = new QSpinBox(this);
     mCloseToQuotaThreshold->setRange(0, 100);
     mCloseToQuotaThreshold->setSingleStep(1);
-    connect(mCloseToQuotaThreshold, SIGNAL(valueChanged(int)),
-            this, SLOT(slotEmitChanged()));
+    connect(mCloseToQuotaThreshold, QOverload<int>::of(&QSpinBox::valueChanged),
+            this, &ConfigModuleTab::slotEmitChanged);
     mCloseToQuotaThreshold->setSuffix(i18n("%"));
 
     hbox->addWidget(mCloseToQuotaThreshold);
@@ -407,8 +401,6 @@ void AppearancePage::ColorsTab::loadColor(bool loadFromConfig)
     if (KMKernel::self()) {
         KConfigGroup reader(KMKernel::self()->config(), "Reader");
 
-        KConfigGroup collectionFolderView(KMKernel::self()->config(), "CollectionFolderView");
-
         static const QColor defaultColor[ numColorNames ] = {
             MessageCore::ColorUtil::self()->quoteLevel1DefaultTextColor(),
             MessageCore::ColorUtil::self()->quoteLevel2DefaultTextColor(),
@@ -459,12 +451,9 @@ void AppearancePage::ColorsTab::save()
         return;
     }
     KConfigGroup reader(KMKernel::self()->config(), "Reader");
-    KConfigGroup collectionFolderView(KMKernel::self()->config(), "CollectionFolderView");
     bool customColors = mCustomColorCheck->isChecked();
     MessageCore::MessageCoreSettings::self()->setUseDefaultColors(!customColors);
 
-    KColorScheme scheme(QPalette::Active, KColorScheme::View);
-
     for (int i = 0; i < numColorNames; ++i) {
         const QString configName = QLatin1String(colorNames[i].configName);
         if (customColors && configName == QLatin1String("UnreadMessageColor")) {
@@ -498,7 +487,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
                         mFolderListGroup = new QButtonGroup(this),
                         Qt::Vertical, KMailSettings::self()->folderListItem());
     vlay->addWidget(mFolderListGroupBox);
-    connect(mFolderListGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFolderListGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
     QHBoxLayout *folderCBHLayout = new QHBoxLayout;
     mFolderQuickSearchCB = new QCheckBox(i18n("Show folder quick search field"), this);
@@ -511,7 +500,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     mFavoriteFoldersViewGroupBox->setTitle(i18n("Show Favorite Folders View"));
     mFavoriteFoldersViewGroupBox->setLayout(new QVBoxLayout());
     mFavoriteFoldersViewGroup = new QButtonGroup(this);
-    connect(mFavoriteFoldersViewGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFavoriteFoldersViewGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
     QRadioButton *favoriteFoldersViewHiddenRadio = new QRadioButton(i18n("Never"), mFavoriteFoldersViewGroupBox);
     mFavoriteFoldersViewGroup->addButton(favoriteFoldersViewHiddenRadio, static_cast<int>(MailCommon::MailCommonSettings::EnumFavoriteCollectionViewMode::HiddenMode));
@@ -532,7 +521,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
     mFolderToolTipsGroupBox->setTitle(i18n("Folder Tooltips"));
     mFolderToolTipsGroupBox->setLayout(new QVBoxLayout());
     mFolderToolTipsGroup = new QButtonGroup(this);
-    connect(mFolderToolTipsGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mFolderToolTipsGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
     QRadioButton *folderToolTipsAlwaysRadio = new QRadioButton(i18n("Always"), mFolderToolTipsGroupBox);
     mFolderToolTipsGroup->addButton(folderToolTipsAlwaysRadio, static_cast< int >(FolderTreeWidget::DisplayAlways));
@@ -550,7 +539,7 @@ AppearancePageLayoutTab::AppearancePageLayoutTab(QWidget *parent)
                         Qt::Vertical, KMailSettings::self()->readerWindowModeItem());
     vlay->addWidget(mReaderWindowModeGroupBox);
 
-    connect(mReaderWindowModeGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mReaderWindowModeGroup, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
     vlay->addStretch(10);   // spacer
 }
@@ -559,7 +548,9 @@ void AppearancePage::LayoutTab::doLoadOther()
 {
     loadWidget(mFolderListGroupBox, mFolderListGroup, KMailSettings::self()->folderListItem());
     loadWidget(mReaderWindowModeGroupBox, mReaderWindowModeGroup, KMailSettings::self()->readerWindowModeItem());
-    loadWidget(mFavoriteFoldersViewGroupBox, mFavoriteFoldersViewGroup, MailCommon::MailCommonSettings::self()->favoriteCollectionViewModeItem());
+    if (KMKernel::self()) {
+        loadWidget(mFavoriteFoldersViewGroupBox, mFavoriteFoldersViewGroup, KMKernel::self()->mailCommonSettings()->favoriteCollectionViewModeItem());
+    }
     loadWidget(mFolderQuickSearchCB, KMailSettings::self()->enableFolderQuickSearchItem());
     const int checkedFolderToolTipsPolicy = KMailSettings::self()->toolTipDisplayPolicy();
     if (checkedFolderToolTipsPolicy >= 0) {
@@ -571,7 +562,9 @@ void AppearancePage::LayoutTab::save()
 {
     saveButtonGroup(mFolderListGroup, KMailSettings::self()->folderListItem());
     saveButtonGroup(mReaderWindowModeGroup, KMailSettings::self()->readerWindowModeItem());
-    saveButtonGroup(mFavoriteFoldersViewGroup, MailCommon::MailCommonSettings::self()->favoriteCollectionViewModeItem());
+    if (KMKernel::self()) {
+        saveButtonGroup(mFavoriteFoldersViewGroup, KMKernel::self()->mailCommonSettings()->favoriteCollectionViewModeItem());
+    }
     saveCheckBox(mFolderQuickSearchCB, KMailSettings::self()->enableFolderQuickSearchItem());
     KMailSettings::self()->setToolTipDisplayPolicy(mFolderToolTipsGroup->checkedId());
 }
@@ -632,8 +625,8 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
 
     connect(aggregationConfigButton, &MessageList::Utils::AggregationConfigButton::configureDialogCompleted,
             this, &AppearancePageHeadersTab::slotSelectDefaultAggregation);
-    connect(mAggregationComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotEmitChanged()));
+    connect(mAggregationComboBox, QOverload<int>::of(&MessageList::Utils::AggregationComboBox::activated),
+            this, &ConfigModuleTab::slotEmitChanged);
 
     // "Theme"
     using MessageList::Utils::ThemeComboBox;
@@ -653,8 +646,8 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
 
     connect(themeConfigButton, &MessageList::Utils::ThemeConfigButton::configureDialogCompleted,
             this, &AppearancePageHeadersTab::slotSelectDefaultTheme);
-    connect(mThemeComboBox, SIGNAL(activated(int)),
-            this, SLOT(slotEmitChanged()));
+    connect(mThemeComboBox, QOverload<int>::of(&MessageList::Utils::ThemeComboBox::activated),
+            this, &ConfigModuleTab::slotEmitChanged);
 
     vlay->addWidget(group);
 
@@ -741,7 +734,7 @@ AppearancePageHeadersTab::AppearancePageHeadersTab(QWidget *parent)
     } // end for loop populating mDateDisplay
 
     vlay->addWidget(mDateDisplayBox);
-    connect(mDateDisplay, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
+    connect(mDateDisplay, QOverload<int>::of(&QButtonGroup::buttonClicked), this, &ConfigModuleTab::slotEmitChanged);
 
     vlay->addStretch(10);   // spacer
 }
@@ -818,7 +811,9 @@ void AppearancePage::HeadersTab::save()
 {
     saveCheckBox(mDisplayMessageToolTips, MessageList::MessageListSettings::self()->messageToolTipEnabledItem());
 
-    KMKernel::self()->savePaneSelection();
+    if (KMKernel::self()) {
+        KMKernel::self()->savePaneSelection();
+    }
     // "Aggregation"
     mAggregationComboBox->writeDefaultConfig();
 
@@ -839,28 +834,45 @@ QString AppearancePage::ReaderTab::helpAnchor() const
     return QStringLiteral("configure-appearance-reader");
 }
 
-AppearancePageReaderTab::AppearancePageReaderTab(QWidget *parent)
+AppearancePageGeneralTab::AppearancePageGeneralTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
     QVBoxLayout *topLayout = new QVBoxLayout(this);
 
+    QGroupBox *readerBox = new QGroupBox(i18n("Message Window"), this);
+    topLayout->addWidget(readerBox);
+
+    QVBoxLayout *readerBoxLayout = new QVBoxLayout(readerBox);
+
     // "Close message window after replying or forwarding" check box:
     populateCheckBox(mCloseAfterReplyOrForwardCheck = new QCheckBox(this),
-                     KMailSettings::self()->closeAfterReplyOrForwardItem());
+                     MessageViewer::MessageViewerSettings::self()->closeAfterReplyOrForwardItem());
     mCloseAfterReplyOrForwardCheck->setToolTip(
         i18n("Close the standalone message window after replying or forwarding the message"));
-    topLayout->addWidget(mCloseAfterReplyOrForwardCheck);
+    readerBoxLayout->addWidget(mCloseAfterReplyOrForwardCheck);
     connect(mCloseAfterReplyOrForwardCheck, &QCheckBox::stateChanged,
             this, &ConfigModuleTab::slotEmitChanged);
 
     mViewerSettings = new MessageViewer::ConfigureWidget;
     connect(mViewerSettings, &MessageViewer::ConfigureWidget::settingsChanged,
             this, &ConfigModuleTab::slotEmitChanged);
-    topLayout->addWidget(mViewerSettings);
+    readerBoxLayout->addWidget(mViewerSettings);
 
     mGravatarConfigWidget = new Gravatar::GravatarConfigWidget;
     connect(mGravatarConfigWidget, &Gravatar::GravatarConfigWidget::configChanged, this, &ConfigModuleTab::slotEmitChanged);
-    topLayout->addWidget(mGravatarConfigWidget);
+    readerBoxLayout->addWidget(mGravatarConfigWidget);
+
+    QGroupBox *systrayBox = new QGroupBox(i18n("System Tray"), this);
+    topLayout->addWidget(systrayBox);
+
+    QVBoxLayout *systrayBoxlayout = new QVBoxLayout(systrayBox);
+
+    // "Enable system tray applet" check box
+    mSystemTrayCheck = new QCheckBox(i18n("Enable system tray icon"), this);
+    systrayBoxlayout->addWidget(mSystemTrayCheck);
+    connect(mSystemTrayCheck, &QCheckBox::stateChanged,
+            this, &ConfigModuleTab::slotEmitChanged);
+
     topLayout->addStretch(100);   // spacer
 }
 
@@ -871,46 +883,19 @@ void AppearancePage::ReaderTab::doResetToDefaultsOther()
 
 void AppearancePage::ReaderTab::doLoadOther()
 {
-    loadWidget(mCloseAfterReplyOrForwardCheck, KMailSettings::self()->closeAfterReplyOrForwardItem());
+    loadWidget(mSystemTrayCheck, KMailSettings::self()->systemTrayEnabledItem());
+    loadWidget(mCloseAfterReplyOrForwardCheck, MessageViewer::MessageViewerSettings::self()->closeAfterReplyOrForwardItem());
     mViewerSettings->readConfig();
     mGravatarConfigWidget->doLoadFromGlobalSettings();
 }
 
 void AppearancePage::ReaderTab::save()
-{
-    saveCheckBox(mCloseAfterReplyOrForwardCheck, KMailSettings::self()->closeAfterReplyOrForwardItem());
-    mViewerSettings->writeConfig();
-    mGravatarConfigWidget->save();
-}
-
-QString AppearancePage::SystemTrayTab::helpAnchor() const
-{
-    return QStringLiteral("configure-appearance-systemtray");
-}
-
-AppearancePageSystemTrayTab::AppearancePageSystemTrayTab(QWidget *parent)
-    : ConfigModuleTab(parent)
-{
-    QVBoxLayout *vlay = new QVBoxLayout(this);
-
-    // "Enable system tray applet" check box
-    mSystemTrayCheck = new QCheckBox(i18n("Enable system tray icon"), this);
-    vlay->addWidget(mSystemTrayCheck);
-    connect(mSystemTrayCheck, &QCheckBox::stateChanged,
-            this, &ConfigModuleTab::slotEmitChanged);
-
-    vlay->addStretch(10);
-}
-
-void AppearancePage::SystemTrayTab::doLoadFromGlobalSettings()
-{
-    loadWidget(mSystemTrayCheck, KMailSettings::self()->systemTrayEnabledItem());
-}
-
-void AppearancePage::SystemTrayTab::save()
 {
     saveCheckBox(mSystemTrayCheck, KMailSettings::self()->systemTrayEnabledItem());
     KMailSettings::self()->save();
+    saveCheckBox(mCloseAfterReplyOrForwardCheck, MessageViewer::MessageViewerSettings::self()->closeAfterReplyOrForwardItem());
+    mViewerSettings->writeConfig();
+    mGravatarConfigWidget->save();
 }
 
 QString AppearancePage::MessageTagTab::helpAnchor() const
@@ -1006,7 +991,6 @@ AppearancePageMessageTagTab::AppearancePageMessageTagTab(QWidget *parent)
     //Extra VBoxLayout for stretchers around settings
     QVBoxLayout *tagsettinggrid = new QVBoxLayout();
     maingrid->addLayout(tagsettinggrid);
-    //tagsettinggrid->addStretch( 10 );
 
     //Groupbox frame
     mTagSettingGroupBox = new QGroupBox(i18n("Ta&g Settings"),
