@@ -50,33 +50,32 @@ public:
     QString helpAnchor() const;
 
     void save() override;
-private Q_SLOTS:
-    void slotConfigureAddressCompletion();
 private:
+    void slotConfigureAddressCompletion();
     void doLoadFromGlobalSettings() override;
     void doResetToDefaultsOther() override;
 
 private:
-    QCheckBox *mShowBalooSearchAddressesInComposer;
-    QCheckBox *mAutoAppSignFileCheck;
-    QCheckBox *mTopQuoteCheck;
-    QCheckBox *mDashDashCheck;
-    QCheckBox *mReplyUsingHtml;
-    QCheckBox *mSmartQuoteCheck;
-    QCheckBox *mStripSignatureCheck;
-    QCheckBox *mQuoteSelectionOnlyCheck;
-    QCheckBox *mAutoRequestMDNCheck;
-    QCheckBox *mShowRecentAddressesInComposer;
-    QCheckBox *mWordWrapCheck;
-    QSpinBox *mWrapColumnSpin;
-    KPluralHandlingSpinBox *mAutoSave;
-    QSpinBox *mMaximumRecipients;
-    QCheckBox *mImprovePlainTextOfHtmlMessage;
-    QSpinBox *mMaximumRecentAddress;
+    QCheckBox *mShowAkonadiSearchAddressesInComposer = nullptr;
+    QCheckBox *mAutoAppSignFileCheck = nullptr;
+    QCheckBox *mTopQuoteCheck = nullptr;
+    QCheckBox *mDashDashCheck = nullptr;
+    QCheckBox *mReplyUsingHtml = nullptr;
+    QCheckBox *mSmartQuoteCheck = nullptr;
+    QCheckBox *mStripSignatureCheck = nullptr;
+    QCheckBox *mQuoteSelectionOnlyCheck = nullptr;
+    QCheckBox *mAutoRequestMDNCheck = nullptr;
+    QCheckBox *mShowRecentAddressesInComposer = nullptr;
+    QCheckBox *mWordWrapCheck = nullptr;
+    QSpinBox *mWrapColumnSpin = nullptr;
+    KPluralHandlingSpinBox *mAutoSave = nullptr;
+    QSpinBox *mMaximumRecipients = nullptr;
+    QCheckBox *mImprovePlainTextOfHtmlMessage = nullptr;
+    QSpinBox *mMaximumRecentAddress = nullptr;
 #ifdef KDEPIM_ENTERPRISE_BUILD
-    KComboBox *mForwardTypeCombo;
-    QCheckBox *mRecipientCheck;
-    QSpinBox *mRecipientSpin;
+    KComboBox *mForwardTypeCombo = nullptr;
+    QCheckBox *mRecipientCheck = nullptr;
+    QSpinBox *mRecipientSpin = nullptr;
 #endif
 };
 
@@ -93,7 +92,7 @@ private:
     void doLoadFromGlobalSettings() override;
     void doResetToDefaultsOther() override;
 private:
-    TemplateParser::TemplatesConfiguration *mWidget;
+    TemplateParser::TemplatesConfiguration *mWidget = nullptr;
 };
 
 class ComposerPageCustomTemplatesTab : public ConfigModuleTab
@@ -109,7 +108,7 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    TemplateParser::CustomTemplates *mWidget;
+    TemplateParser::CustomTemplates *mWidget = nullptr;
 };
 
 class ComposerPageSubjectTab : public ConfigModuleTab
@@ -126,10 +125,10 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    PimCommon::SimpleStringListEditor *mReplyListEditor;
-    QCheckBox *mReplaceReplyPrefixCheck;
-    PimCommon::SimpleStringListEditor *mForwardListEditor;
-    QCheckBox *mReplaceForwardPrefixCheck;
+    PimCommon::SimpleStringListEditor *mReplyListEditor = nullptr;
+    QCheckBox *mReplaceReplyPrefixCheck = nullptr;
+    PimCommon::SimpleStringListEditor *mForwardListEditor = nullptr;
+    QCheckBox *mReplaceForwardPrefixCheck = nullptr;
 };
 
 class ComposerPageCharsetTab : public ConfigModuleTab
@@ -149,8 +148,8 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    PimCommon::SimpleStringListEditor *mCharsetListEditor;
-    QCheckBox *mKeepReplyCharsetCheck;
+    PimCommon::SimpleStringListEditor *mCharsetListEditor = nullptr;
+    QCheckBox *mKeepReplyCharsetCheck = nullptr;
 };
 
 class ComposerPageHeadersTab : public ConfigModuleTab
@@ -174,14 +173,14 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    QCheckBox *mCreateOwnMessageIdCheck;
-    QLineEdit *mMessageIdSuffixEdit;
-    ListView *mHeaderList;
-    QPushButton *mRemoveHeaderButton;
-    QLineEdit *mTagNameEdit;
-    QLineEdit *mTagValueEdit;
-    QLabel *mTagNameLabel;
-    QLabel *mTagValueLabel;
+    QCheckBox *mCreateOwnMessageIdCheck = nullptr;
+    QLineEdit *mMessageIdSuffixEdit = nullptr;
+    ListView *mHeaderList = nullptr;
+    QPushButton *mRemoveHeaderButton = nullptr;
+    QLineEdit *mTagNameEdit = nullptr;
+    QLineEdit *mTagValueEdit = nullptr;
+    QLabel *mTagNameLabel = nullptr;
+    QLabel *mTagValueLabel = nullptr;
 };
 
 class ComposerPageAttachmentsTab : public ConfigModuleTab
@@ -200,10 +199,10 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    QCheckBox *mOutlookCompatibleCheck;
-    QCheckBox *mMissingAttachmentDetectionCheck;
-    PimCommon::SimpleStringListEditor *mAttachWordsListEditor;
-    QSpinBox *mMaximumAttachmentSize;
+    QCheckBox *mOutlookCompatibleCheck = nullptr;
+    QCheckBox *mMissingAttachmentDetectionCheck = nullptr;
+    PimCommon::SimpleStringListEditor *mAttachWordsListEditor = nullptr;
+    QSpinBox *mMaximumAttachmentSize = nullptr;
 };
 
 class ComposerPageAutoCorrectionTab : public ConfigModuleTab
@@ -220,7 +219,7 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    PimCommon::AutoCorrectionWidget *autocorrectionWidget;
+    PimCommon::AutoCorrectionWidget *autocorrectionWidget = nullptr;
 };
 
 class ComposerPageAutoImageResizeTab : public ConfigModuleTab
@@ -237,7 +236,7 @@ private:
     void doResetToDefaultsOther() override;
 
 private:
-    MessageComposer::ImageScalingWidget *autoResizeWidget;
+    MessageComposer::ImageScalingWidget *autoResizeWidget = nullptr;
 };
 
 class KMAIL_EXPORT ComposerPage : public ConfigModuleWithTabs
