@@ -25,14 +25,9 @@ using namespace PimCommon::ConfigureImmutableWidgetUtils;
 #include "MessageViewer/PrintingSettings"
 #include "messageviewer/messageviewersettings.h"
 
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
 #include "MessageViewer/PrintingSettings"
-#endif
 
-#include <KCModuleProxy>
-#include <KCModuleInfo>
 #include <KLocalizedString>
-#include <KConfigGroup>
 #include <QHBoxLayout>
 
 #include <WebEngineViewer/NetworkPluginUrlInterceptorConfigureWidget>
@@ -54,10 +49,8 @@ MiscPage::MiscPage(QWidget *parent)
     InviteTab *inviteTab = new InviteTab();
     addTab(inviteTab, i18n("Invitations"));
 
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
     MiscPagePrintingTab *printingTab = new MiscPagePrintingTab();
     addTab(printingTab, i18n("Printing"));
-#endif
 }
 
 QString MiscPageFolderTab::helpAnchor() const
@@ -80,9 +73,9 @@ MiscPageFolderTab::MiscPageFolderTab(QWidget *parent)
         i18n(KMailSettings::self()->excludeImportantMailFromExpiryItem()->whatsThis().toUtf8()));
 
     connect(mMMTab.mExcludeImportantFromExpiry, &QCheckBox::stateChanged, this, &MiscPageFolderTab::slotEmitChanged);
-    connect(mMMTab.mLoopOnGotoUnread, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &MiscPageFolderTab::slotEmitChanged);
-    connect(mMMTab.mActionEnterFolder, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &MiscPageFolderTab::slotEmitChanged);
-    connect(mMMTab.mDelayedMarkTime, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &MiscPageFolderTab::slotEmitChanged);
+    connect(mMMTab.mLoopOnGotoUnread, QOverload<int>::of(&KComboBox::activated), this, &MiscPageFolderTab::slotEmitChanged);
+    connect(mMMTab.mActionEnterFolder, QOverload<int>::of(&KComboBox::activated), this, &MiscPageFolderTab::slotEmitChanged);
+    connect(mMMTab.mDelayedMarkTime, QOverload<int>::of(&QSpinBox::valueChanged), this, &MiscPageFolderTab::slotEmitChanged);
     connect(mMMTab.mDelayedMarkAsRead, &QAbstractButton::toggled, mMMTab.mDelayedMarkTime, &QWidget::setEnabled);
     connect(mMMTab.mDelayedMarkAsRead, &QAbstractButton::toggled, this, &ConfigModuleTab::slotEmitChanged);
     connect(mMMTab.mShowPopupAfterDnD, &QCheckBox::stateChanged, this, &MiscPageFolderTab::slotEmitChanged);
@@ -152,7 +145,6 @@ void MiscPage::InviteTab::doResetToDefaultsOther()
     mInvitationUi->doResetToDefaultsOther();
 }
 
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
 MiscPagePrintingTab::MiscPagePrintingTab(QWidget *parent)
     : ConfigModuleTab(parent)
 {
@@ -177,5 +169,3 @@ void MiscPagePrintingTab::save()
 {
     mPrintingUi->save();
 }
-
-#endif
