@@ -21,7 +21,6 @@
 #include "kmail_export.h"
 #include "ui_miscpagemaintab.h"
 #include "configuredialog_p.h"
-#include "config-kmail.h"
 
 namespace MailCommon {
 class FolderRequester;
@@ -46,7 +45,7 @@ private:
 
 private:
     Ui_MiscMainTab mMMTab;
-    MailCommon::FolderRequester *mOnStartupOpenFolder;
+    MailCommon::FolderRequester *mOnStartupOpenFolder = nullptr;
 };
 
 class MiscPageInviteTab : public ConfigModuleTab
@@ -61,7 +60,7 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    MessageViewer::InvitationSettings *mInvitationUi;
+    MessageViewer::InvitationSettings *mInvitationUi = nullptr;
 };
 
 class KMAIL_EXPORT MiscPage : public ConfigModuleWithTabs
@@ -75,7 +74,6 @@ public:
     typedef MiscPageInviteTab InviteTab;
 };
 
-#ifdef WEBENGINEVIEWER_PRINT_SUPPORT
 class MiscPagePrintingTab : public ConfigModuleTab
 {
     Q_OBJECT
@@ -88,8 +86,7 @@ private:
     void doLoadFromGlobalSettings() override;
 
 private:
-    MessageViewer::PrintingSettings *mPrintingUi;
+    MessageViewer::PrintingSettings *mPrintingUi = nullptr;
 };
-#endif
 
 #endif // CONFIGUREMISCPAGE_H
