@@ -34,13 +34,11 @@ public:
     void initialize() override;
     void defaults() override;
 
-private Q_SLOTS:
-    void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
-
 private:
+    void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
     void initializeAgentPlugins();
     PimCommon::PluginUtilData createAgentPluginData(const QString &interfaceName, const QString &path);
-    bool agentActivateState(const QString &interfaceName, const QString &pathName, bool &failed);
+    bool agentActivateState(const QString &interfaceName, const QString &pathName);
     void changeAgentActiveState(const QString &interfaceName, const QString &path, bool enable);
     void saveAkonadiAgent();
     QList<PluginItem *> mPluginEditorItems;
