@@ -45,10 +45,8 @@ private:
     void doLoadOther() override;
 
 private:
-    Ui_SecurityPageGeneralTab mSGTab;
-
-private Q_SLOTS:
     void slotLinkClicked(const QString &link);
+    Ui_SecurityPageGeneralTab mSGTab;
 };
 
 class SecurityPageMDNTab : public ConfigModuleTab
@@ -64,12 +62,10 @@ private:
     void doLoadOther() override;
 
 private:
-    QButtonGroup *mMDNGroup;
-    QButtonGroup *mOrigQuoteGroup;
-    Ui_SecurityPageMDNTab mUi;
-
-private Q_SLOTS:
     void slotLinkClicked(const QString &link);
+    QButtonGroup *mMDNGroup = nullptr;
+    QButtonGroup *mOrigQuoteGroup = nullptr;
+    Ui_SecurityPageMDNTab mUi;
 };
 
 class SecurityPageComposerCryptoTab : public ConfigModuleTab
@@ -88,7 +84,7 @@ private:
     void doLoadOther() override;
 
 private:
-    Ui::ComposerCryptoConfiguration *mWidget;
+    Ui::ComposerCryptoConfiguration *mWidget = nullptr;
 };
 
 class SecurityPageWarningTab : public ConfigModuleTab
@@ -111,7 +107,7 @@ private:
     void doLoadOther() override;
 
 private:
-    Ui::WarningConfiguration *mWidget;
+    Ui::WarningConfiguration *mWidget = nullptr;
 };
 
 class SecurityPageSMimeTab : public ConfigModuleTab
@@ -132,8 +128,8 @@ private:
     void doLoadOther() override;
 
 private:
-    Ui::SMimeConfiguration *mWidget;
-    QGpgME::CryptoConfig *mConfig;
+    Ui::SMimeConfiguration *mWidget = nullptr;
+    QGpgME::CryptoConfig *mConfig = nullptr;
 };
 
 class GpgSettingsDialog : public KCMultiDialog
@@ -155,7 +151,7 @@ public:
 
     QString helpAnchor() const override;
 
-    typedef SecurityPageGeneralTab GeneralTab;
+    typedef SecurityPageGeneralTab ReadingTab;
     typedef SecurityPageMDNTab MDNTab;
     typedef SecurityPageComposerCryptoTab ComposerCryptoTab;
     typedef SecurityPageWarningTab WarningTab;
