@@ -33,15 +33,14 @@ public:
 
     Akonadi::Item selectedContact() const;
 
-private Q_SLOTS:
+private:
     void slotSelectionChanged();
 
     void slotDoubleClicked();
-private:
     void readConfig();
     void writeConfig();
-    Akonadi::EmailAddressSelectionWidget *mEmailSelectionWidget;
-    QPushButton *mOkButton;
+    Akonadi::EmailAddressSelectionWidget *mEmailSelectionWidget = nullptr;
+    QPushButton *mOkButton = nullptr;
 };
 
 #endif // ADDEMAILTOEXISTINGCONTACTDIALOG_H
