@@ -46,18 +46,17 @@ public Q_SLOTS:
     /// @reimp
     void attachMyPublicKey() override;
 
-private Q_SLOTS:
+private:
     void identityChanged();
-    void actionsCreated();
+    void slotActionsCreated();
     void addAttachmentItems(const Akonadi::Item::List &items);
     void selectionChanged();
     void onShowAttachment(KMime::Content *content, const QByteArray &charset);
     void doubleClicked(const QModelIndex &itemClicked);
     void slotSelectAllAttachment();
 
-private:
-    KMComposerWin *mComposer;
-    AttachmentView *mView;
+    KMComposerWin *mComposer = nullptr;
+    AttachmentView *mView = nullptr;
 };
 } // namespace KMail
 
