@@ -26,6 +26,7 @@
 #define KMAIL_ATTACHMENTVIEW_H
 
 #include <QTreeView>
+#include <KConfigGroup>
 
 class QContextMenuEvent;
 class QToolButton;
@@ -77,6 +78,7 @@ private:
     QToolButton *mToolButton = nullptr;
     QLabel *mInfoAttachment = nullptr;
     QWidget *mWidget = nullptr;
+    KConfigGroup grp;
 };
 } // namespace KMail
 
