@@ -72,6 +72,7 @@ class KMComposerGlobalAction;
 class KMailPluginEditorManagerInterface;
 class KMailPluginEditorCheckBeforeSendManagerInterface;
 class KMailPluginEditorInitManagerInterface;
+class IncorrectIdentityFolderWarning;
 namespace MailTransport {
 class Transport;
 }
@@ -306,7 +307,7 @@ private Q_SLOTS:
      * Change crypto plugin to be used for signing/encrypting messages,
      * or switch to built-in OpenPGP code.
      */
-    void slotSelectCryptoModule(bool init = false);
+    void slotSelectCryptoModule(bool init);
 
     /**
      * XML-GUI stuff
@@ -315,11 +316,6 @@ private Q_SLOTS:
     void slotUpdateToolbars();
     void slotEditKeys();
 
-    /**
-     * Read settings from app's config file.
-     */
-    void readConfig(bool reload = false);
-
     /**
      * Change window title to given string.
      */
@@ -415,6 +411,11 @@ public: // kmcommand
     QList<KToggleAction *> customToolsList() const;
     QList<QAction *> pluginToolsActionListForPopupMenu() const;
 private:
+    /**
+     * Read settings from app's config file.
+     */
+    void readConfig(bool reload = false);
+
     QUrl insertFile();
     /**
      * Updates the visibility and text of the signature and encryption state indicators.
@@ -433,7 +434,7 @@ private:
      * should not be there they are removed. Those that are needed are
      * created if necessary.
      */
-    void rethinkFields(bool fromslot = false);
+    void rethinkFields(bool fromslot = false, bool forceAllHeaders = false);
 
     /**
       Connect signals for moving focus by arrow keys. Returns next edit.
@@ -531,6 +532,10 @@ private:
         KeyOk,
         NoKey
     };
+    void slotCryptoModuleSelected();
+    void slotFccIsInvalid();
+    void slotIdentityDeleted(uint uoid);
+    void slotTransportRemoved(int id, const QString &name);
 
     void updateComposerAfterIdentityChanged(const KIdentityManagement::Identity &ident, uint uoid, bool wasModified);
 
@@ -541,79 +546,80 @@ private:
     Akonadi::Collection mCollectionForNewMessage;
     QMap<QByteArray, QString> mExtraHeaders;
 
-    QWidget *mMainWidget;
-    MessageComposer::ComposerLineEdit *mEdtFrom;
-    MessageComposer::ComposerLineEdit *mEdtReplyTo;
-    PimCommon::LineEditWithAutoCorrection *mEdtSubject;
-    QLabel *mLblIdentity;
-    QLabel *mLblTransport;
-    QLabel *mLblFcc;
-    QLabel *mLblFrom;
-    QLabel *mLblReplyTo;
-    QLabel *mLblSubject;
-    QLabel *mDictionaryLabel;
-    QLabel *mCursorLineLabel;
-    QLabel *mCursorColumnLabel;
-    QLabel *mStatusbarLabel;
-    bool mDone;
+    QWidget *mMainWidget = nullptr;
+    MessageComposer::ComposerLineEdit *mEdtFrom = nullptr;
+    MessageComposer::ComposerLineEdit *mEdtReplyTo = nullptr;
+    PimCommon::LineEditWithAutoCorrection *mEdtSubject = nullptr;
+    QLabel *mLblIdentity = nullptr;
+    QLabel *mLblTransport = nullptr;
+    QLabel *mLblFcc = nullptr;
+    QLabel *mLblFrom = nullptr;
+    QLabel *mLblReplyTo = nullptr;
+    QLabel *mLblSubject = nullptr;
+    QLabel *mDictionaryLabel = nullptr;
+    QLabel *mCursorLineLabel = nullptr;
+    QLabel *mCursorColumnLabel = nullptr;
+    QLabel *mStatusbarLabel = nullptr;
+    bool mDone = false;
 
     KMime::Message::Ptr mMsg;
-    QGridLayout *mGrid;
+    QGridLayout *mGrid = nullptr;
     QString mTextSelection;
     QString mCustomTemplate;
-    bool mLastSignActionState;
-    bool mLastEncryptActionState;
-    bool mSigningAndEncryptionExplicitlyDisabled;
-    bool mLastIdentityHasSigningKey;
-    bool mLastIdentityHasEncryptionKey;
+    bool mLastSignActionState = false;
+    bool mLastEncryptActionState = false;
+    bool mSigningAndEncryptionExplicitlyDisabled = false;
+    bool mLastIdentityHasSigningKey = false;
+    bool mLastIdentityHasEncryptionKey = false;
     Akonadi::Collection mFolder;
-    long mShowHeaders;
-    bool mForceDisableHtml;     // Completely disable any HTML. Useful when sending invitations in the
+    long mShowHeaders = 0;
+    bool mForceDisableHtml = false;     // Completely disable any HTML. Useful when sending invitations in the
     // mail body.
-    int mNumHeaders;
-    QFont mBodyFont, mFixedFont;
-    uint mId;
+    int mNumHeaders = 0;
+    QFont mBodyFont;
+    QFont mFixedFont;
+    uint mId = 0;
     TemplateContext mContext;
 
-    KRecentFilesAction *mRecentAction;
+    KRecentFilesAction *mRecentAction = nullptr;
 
-    KToggleAction *mSignAction;
-    KToggleAction *mEncryptAction;
-    KToggleAction *mRequestMDNAction;
-    KToggleAction *mUrgentAction;
-    KToggleAction *mAllFieldsAction;
-    KToggleAction *mFromAction;
-    KToggleAction *mReplyToAction;
-    KToggleAction *mSubjectAction;
-    KToggleAction *mIdentityAction;
-    KToggleAction *mTransportAction;
-    KToggleAction *mFccAction;
-    KToggleAction *mWordWrapAction;
-    KToggleAction *mFixedFontAction;
-    KToggleAction *mAutoSpellCheckingAction;
-    KToggleAction *mDictionaryAction;
-    KToggleAction *mSnippetAction;
-    QAction *mAppendSignature;
-    QAction *mPrependSignature;
-    QAction *mInsertSignatureAtCursorPosition;
+    KToggleAction *mSignAction = nullptr;
+    KToggleAction *mEncryptAction = nullptr;
+    KToggleAction *mRequestMDNAction = nullptr;
+    KToggleAction *mUrgentAction = nullptr;
+    KToggleAction *mAllFieldsAction = nullptr;
+    KToggleAction *mFromAction = nullptr;
+    KToggleAction *mReplyToAction = nullptr;
+    KToggleAction *mSubjectAction = nullptr;
+    KToggleAction *mIdentityAction = nullptr;
+    KToggleAction *mTransportAction = nullptr;
+    KToggleAction *mFccAction = nullptr;
+    KToggleAction *mWordWrapAction = nullptr;
+    KToggleAction *mFixedFontAction = nullptr;
+    KToggleAction *mAutoSpellCheckingAction = nullptr;
+    KToggleAction *mDictionaryAction = nullptr;
+    KToggleAction *mSnippetAction = nullptr;
+    QAction *mAppendSignature = nullptr;
+    QAction *mPrependSignature = nullptr;
+    QAction *mInsertSignatureAtCursorPosition = nullptr;
 
-    KToggleAction *mMarkupAction;
+    KToggleAction *mMarkupAction = nullptr;
 
-    CodecAction *mCodecAction;
-    KSelectAction *mCryptoModuleAction;
+    CodecAction *mCodecAction = nullptr;
+    KSelectAction *mCryptoModuleAction = nullptr;
 
-    QAction *mFindText;
-    QAction *mFindNextText;
-    QAction *mReplaceText;
-    QAction *mSelectAll;
+    QAction *mFindText = nullptr;
+    QAction *mFindNextText = nullptr;
+    QAction *mReplaceText = nullptr;
+    QAction *mSelectAll = nullptr;
 
-    QSplitter *mHeadersToEditorSplitter;
-    QWidget *mHeadersArea;
-    QSplitter *mSplitter;
-    QSplitter *mSnippetSplitter;
-    QByteArray mOriginalPreferredCharset;
+    QSplitter *mHeadersToEditorSplitter = nullptr;
+    QWidget *mHeadersArea = nullptr;
+    QSplitter *mSplitter = nullptr;
+    QSplitter *mSnippetSplitter = nullptr;
+    QByteArray mOriginalPreferredCharset = nullptr;
 
-    MessageComposer::Composer *mDummyComposer;
+    MessageComposer::Composer *mDummyComposer = nullptr;
     // used for auto saving, printing, etc. Not for sending, which happens in ComposerViewBase
     QList< MessageComposer::Composer * > mMiscComposers;
 
@@ -622,30 +628,31 @@ private:
     QString mdbusObjectPath;
     static int s_composerNumber;
 
-    MessageComposer::ComposerViewBase *mComposerBase;
+    MessageComposer::ComposerViewBase *mComposerBase = nullptr;
 
-    SnippetWidget *mSnippetWidget;
-    PimCommon::CustomToolsWidgetNg *mCustomToolsWidget;
-    AttachmentMissingWarning *mAttachmentMissing;
-    ExternalEditorWarning *mExternalEditorWarning;
-    QTimer *mVerifyMissingAttachment;
-    MailCommon::FolderRequester *mFccFolder;
-    bool mPreventFccOverwrite;
-    bool mCheckForForgottenAttachments;
-    bool mWasModified;
-    CryptoStateIndicatorWidget *mCryptoStateIndicatorWidget;
-    bool mSendNowByShortcutUsed;
-    KSplitterCollapserButton *mSnippetSplitterCollapser;
-    KToggleAction *mFollowUpToggleAction;
-    StatusBarLabelToggledState *mStatusBarLabelToggledOverrideMode;
-    StatusBarLabelToggledState *mStatusBarLabelSpellCheckingChangeMode;
-    PotentialPhishingEmailWarning *mPotentialPhishingEmailWarning;
-    KMComposerGlobalAction *mGlobalAction;
-    KPIMTextEdit::RichTextEditorWidget *mRichTextEditorwidget;
+    SnippetWidget *mSnippetWidget = nullptr;
+    PimCommon::CustomToolsWidgetNg *mCustomToolsWidget = nullptr;
+    AttachmentMissingWarning *mAttachmentMissing = nullptr;
+    ExternalEditorWarning *mExternalEditorWarning = nullptr;
+    QTimer *mVerifyMissingAttachment = nullptr;
+    MailCommon::FolderRequester *mFccFolder = nullptr;
+    bool mPreventFccOverwrite = false;
+    bool mCheckForForgottenAttachments = false;
+    bool mWasModified = false;
+    CryptoStateIndicatorWidget *mCryptoStateIndicatorWidget = nullptr;
+    bool mSendNowByShortcutUsed = false;
+    KSplitterCollapserButton *mSnippetSplitterCollapser = nullptr;
+    KToggleAction *mFollowUpToggleAction = nullptr;
+    StatusBarLabelToggledState *mStatusBarLabelToggledOverrideMode = nullptr;
+    StatusBarLabelToggledState *mStatusBarLabelSpellCheckingChangeMode = nullptr;
+    PotentialPhishingEmailWarning *mPotentialPhishingEmailWarning = nullptr;
+    IncorrectIdentityFolderWarning *mIncorrectIdentityFolderWarning = nullptr;
+    KMComposerGlobalAction *mGlobalAction = nullptr;
+    KPIMTextEdit::RichTextEditorWidget *mRichTextEditorwidget = nullptr;
 
-    KMailPluginEditorManagerInterface *mPluginEditorManagerInterface;
-    KMailPluginEditorCheckBeforeSendManagerInterface *mPluginEditorCheckBeforeSendManagerInterface;
-    KMailPluginEditorInitManagerInterface *mPluginEditorInitManagerInterface;
+    KMailPluginEditorManagerInterface *mPluginEditorManagerInterface = nullptr;
+    KMailPluginEditorCheckBeforeSendManagerInterface *mPluginEditorCheckBeforeSendManagerInterface = nullptr;
+    KMailPluginEditorInitManagerInterface *mPluginEditorInitManagerInterface = nullptr;
 };
 
 #endif
