@@ -32,13 +32,11 @@ public:
 
     void fillList(const QStringList &lst);
 
-private Q_SLOTS:
-    void slotSave();
-
 private:
+    void slotSave();
     void readConfig();
     void writeConfig();
-    PotentialPhishingDetailWidget *mPotentialPhishingDetailWidget;
+    PotentialPhishingDetailWidget *mPotentialPhishingDetailWidget = nullptr;
 };
 
 #endif // POTENTIALPHISHINGDETAILDIALOG_H
