@@ -64,6 +64,9 @@ bool PotentialPhishingEmailJob::start()
             QString tname, temail;
             KEmailAddress::extractEmailAddressAndName(addr, temail, tname);    // ignore return value
             // which is always false
+            if (tname.startsWith(QLatin1Char('@'))) { //Special case when name is just @foo <...> it mustn't recognize as a valid email
+                continue;
+            }
             if (tname.contains(QLatin1Char('@'))) { //Potential address
                 if (tname.startsWith(QLatin1Char('<')) && tname.endsWith(QLatin1Char('>'))) {
                     tname = tname.mid(1, tname.length() - 2);
