@@ -32,11 +32,13 @@ public:
     ~PotentialPhishingEmailJob();
 
     void setEmailWhiteList(const QStringList &emails);
-    void setEmails(const QStringList &emails);
+    void setPotentialPhishingEmails(const QStringList &emails);
 
     QStringList potentialPhisingEmails() const;
     bool start();
 
+    QStringList checkEmails() const;
+
 Q_SIGNALS:
     void potentialPhishingEmailsFound(const QStringList &emails);
 
