@@ -36,11 +36,11 @@ public:
 
 private:
     void updateShowAlwaysIndicator();
-    QLabel *mSignatureStateIndicator;
-    QLabel *mEncryptionStateIndicator;
-    bool mShowAlwaysIndicator;
-    bool mIsSign;
-    bool mIsEncrypted;
+    QLabel *mSignatureStateIndicator = nullptr;
+    QLabel *mEncryptionStateIndicator = nullptr;
+    bool mShowAlwaysIndicator = true;
+    bool mIsSign = false;
+    bool mIsEncrypted = false;
 };
 
 #endif // CRYPTOSTATEINDICATORWIDGET_H
