@@ -58,11 +58,11 @@ public:
     bool operator==(const FolderArchiveAccountInfo &other) const;
 
 private:
-    Akonadi::Collection::Id mArchiveTopLevelCollectionId;
+    Akonadi::Collection::Id mArchiveTopLevelCollectionId = -1;
     QString mInstanceName;
-    FolderArchiveAccountInfo::FolderArchiveType mArchiveType;
-    bool mEnabled;
-    bool mKeepExistingStructure;
+    FolderArchiveAccountInfo::FolderArchiveType mArchiveType = UniqueFolder;
+    bool mEnabled = false;
+    bool mKeepExistingStructure = false;
 };
 
 #endif // FOLDERARCHIVEACCOUNTINFO_H
