@@ -54,18 +54,17 @@ public Q_SLOTS:
     void slotCollectionRemoved(const Akonadi::Collection &collection);
     void slotInstanceRemoved(const Akonadi::AgentInstance &instance);
 
-private Q_SLOTS:
+private:
     void slotFetchParentCollection(KJob *job);
     void slotFetchCollection(KJob *job);
 
-private:
     FolderArchiveAccountInfo *infoFromInstanceName(const QString &instanceName) const;
     void nextJob();
     void removeInfo(const QString &instanceName);
     QQueue<FolderArchiveAgentJob *> mJobQueue;
-    FolderArchiveAgentJob *mCurrentJob;
+    FolderArchiveAgentJob *mCurrentJob = nullptr;
     QList<FolderArchiveAccountInfo *> mListAccountInfo;
-    FolderArchiveCache *mFolderArchiveCache;
+    FolderArchiveCache *mFolderArchiveCache = nullptr;
 };
 
 #endif // FOLDERARCHIVEMANAGER_H
