@@ -20,7 +20,7 @@
 #include <QDialog>
 #include <QUrl>
 class QButtonGroup;
-class KComboBox;
+class QComboBox;
 class KUrlRequester;
 
 class IdentityAddVcardDialog : public QDialog
@@ -41,9 +41,9 @@ public:
     QUrl existingVCard() const;
 
 private:
-    QButtonGroup *mButtonGroup;
-    KComboBox *mComboBox;
-    KUrlRequester *mVCardPath;
+    QButtonGroup *mButtonGroup = nullptr;
+    QComboBox *mComboBox = nullptr;
+    KUrlRequester *mVCardPath = nullptr;
 };
 
 #endif // IDENTITYADDVCARDDIALOG_H
