@@ -88,68 +88,65 @@ public:
 
     void updateIdentity(KIdentityManagement::Identity &ident);
 
-protected Q_SLOTS:
+private:
     void slotAboutToShow(int);
-
     // copy default templates to identity templates
     void slotCopyGlobal();
-
-private Q_SLOTS:
     void slotAccepted();
     void slotDelayedButtonClicked(KJob *);
     void slotEditVcard();
     void slotRefreshDefaultDomainName();
     void slotVCardRemoved();
     void slotHelp();
-private:
+
     bool keyMatchesEmailAddress(const GpgME::Key &key, const QString &email);
     bool checkFolderExists(const QString &folder);
     bool validateAddresses(const QString &addresses);
     void updateVcardButton();
     void editVcard(const QString &filename);
 
-private:
-    // "general" tab:
-    KLineEdit *mNameEdit;
-    KLineEdit *mOrganizationEdit;
-    KLineEdit *mEmailEdit;
-    KEditListWidget *mAliasEdit;
-    // "cryptography" tab:
-    QWidget *mCryptographyTab;
-    KeySelectionCombo *mPGPSigningKeyRequester;
-    KeySelectionCombo *mPGPEncryptionKeyRequester;
-    KeySelectionCombo *mSMIMESigningKeyRequester;
-    KeySelectionCombo *mSMIMEEncryptionKeyRequester;
-    KComboBox *mPreferredCryptoMessageFormat;
-    QCheckBox *mAutoSign;
-    QCheckBox *mAutoEncrypt;
-    // "advanced" tab:
-    KLineEdit *mReplyToEdit;
-    KLineEdit *mBccEdit;
-    KLineEdit *mCcEdit;
-    Sonnet::DictionaryComboBox *mDictionaryCombo;
-    IdentityFolderRequester *mFccFolderRequester;
-    QCheckBox *mSentMailFolderCheck;
-    IdentityFolderRequester *mDraftsFolderRequester;
-    IdentityFolderRequester *mTemplatesFolderRequester;
-    QCheckBox *mTransportCheck;
-    MailTransport::TransportComboBox *mTransportCombo;
-    QCheckBox *mAttachMyVCard;
     QString mVcardFilename;
-    QPushButton *mEditVCard;
-    PimCommon::AutoCorrectionLanguage *mAutoCorrectionLanguage;
-    KLineEdit *mDefaultDomainEdit;
+
+    // "general" tab:
+    KLineEdit *mNameEdit = nullptr;
+    KLineEdit *mOrganizationEdit = nullptr;
+    KLineEdit *mEmailEdit = nullptr;
+    KEditListWidget *mAliasEdit = nullptr;
+    // "cryptography" tab:
+    QWidget *mCryptographyTab = nullptr;
+    KeySelectionCombo *mPGPSigningKeyRequester = nullptr;
+    KeySelectionCombo *mPGPEncryptionKeyRequester = nullptr;
+    KeySelectionCombo *mSMIMESigningKeyRequester = nullptr;
+    KeySelectionCombo *mSMIMEEncryptionKeyRequester = nullptr;
+    KComboBox *mPreferredCryptoMessageFormat = nullptr;
+    QCheckBox *mAutoSign = nullptr;
+    QCheckBox *mAutoEncrypt = nullptr;
+    // "advanced" tab:
+    KLineEdit *mReplyToEdit = nullptr;
+    KLineEdit *mBccEdit = nullptr;
+    KLineEdit *mCcEdit = nullptr;
+    Sonnet::DictionaryComboBox *mDictionaryCombo = nullptr;
+    IdentityFolderRequester *mFccFolderRequester = nullptr;
+    QCheckBox *mSentMailFolderCheck = nullptr;
+    IdentityFolderRequester *mDraftsFolderRequester = nullptr;
+    IdentityFolderRequester *mTemplatesFolderRequester = nullptr;
+    QCheckBox *mTransportCheck = nullptr;
+    MailTransport::TransportComboBox *mTransportCombo = nullptr;
+    QCheckBox *mAttachMyVCard = nullptr;
+    QPushButton *mEditVCard = nullptr;
+    PimCommon::AutoCorrectionLanguage *mAutoCorrectionLanguage = nullptr;
+    KLineEdit *mDefaultDomainEdit = nullptr;
 
     // "templates" tab:
-    TemplateParser::TemplatesConfiguration *mWidget;
-    QCheckBox *mCustom;
-    QPushButton *mCopyGlobal;
+    TemplateParser::TemplatesConfiguration *mWidget = nullptr;
+    QCheckBox *mCustom = nullptr;
+    QPushButton *mCopyGlobal = nullptr;
     // "signature" tab:
-    KIdentityManagement::SignatureConfigurator *mSignatureConfigurator;
+    KIdentityManagement::SignatureConfigurator *mSignatureConfigurator = nullptr;
     // "X-Face" tab:
-    KMail::XFaceConfigurator *mXFaceConfigurator;
-    QTabWidget *mTabWidget;
-    IdentityInvalidFolder *mIdentityInvalidFolder;
+    KMail::XFaceConfigurator *mXFaceConfigurator = nullptr;
+    QTabWidget *mTabWidget = nullptr;
+    IdentityInvalidFolder *mIdentityInvalidFolder = nullptr;
 };
 } // namespace KMail
 
