@@ -19,8 +19,7 @@
 #define IDENTITYINVALIDFOLDER_H
 
 #include <KMessageWidget>
-namespace KMail
-{
+namespace KMail {
 class IdentityInvalidFolder : public KMessageWidget
 {
     Q_OBJECT
