@@ -28,17 +28,12 @@
 
 struct CreateForwardMessageJobSettings
 {
-    CreateForwardMessageJobSettings()
-        : mIdentity(0)
-    {
-    }
-
     QUrl mUrl;
     Akonadi::Item mItem;
     KMime::Message::Ptr mMsg;
     QString mTemplate;
     QString mSelection;
-    uint mIdentity;
+    uint mIdentity = 0;
 };
 
 class CreateForwardMessageJob : public QObject
@@ -52,7 +47,7 @@ public:
     void setSettings(const CreateForwardMessageJobSettings &value);
 
 private:
-    MessageComposer::MessageFactoryNG *mMessageFactory;
+    MessageComposer::MessageFactoryNG *mMessageFactory = nullptr;
     void slotCreateForwardDone(const KMime::Message::Ptr &msg);
     CreateForwardMessageJobSettings mSettings;
 };
