@@ -26,8 +26,6 @@
 #include <KMime/Message>
 #include <KEmailAddress>
 #include <MailCommon/MailUtil>
-#include <QUrl>
-#include <QDebug>
 
 CreateReplyMessageJob::CreateReplyMessageJob(QObject *parent)
     : QObject(parent)
@@ -46,7 +44,7 @@ void CreateReplyMessageJob::setSettings(const CreateReplyMessageJobSettings &set
 }
 
 /// Small helper function to get the composer context from a reply
-inline KMail::Composer::TemplateContext replyContext(MessageComposer::MessageFactoryNG::MessageReply reply)
+inline KMail::Composer::TemplateContext replyContext(const MessageComposer::MessageFactoryNG::MessageReply &reply)
 {
     if (reply.replyAll) {
         return KMail::Composer::ReplyToAll;
@@ -57,7 +55,8 @@ inline KMail::Composer::TemplateContext replyContext(MessageComposer::MessageFac
 
 void CreateReplyMessageJob::start()
 {
-    mMessageFactory = new MessageComposer::MessageFactoryNG(mSettings.mMsg, mSettings.mItem.id(), MailCommon::Util::updatedCollection(mSettings.mItem.parentCollection()));
+    const auto col = CommonKernel->collectionFromId(mSettings.mItem.parentCollection().id());
+    mMessageFactory = new MessageComposer::MessageFactoryNG(mSettings.mMsg, mSettings.mItem.id(), col);
     mMessageFactory->setIdentityManager(KMKernel::self()->identityManager());
     mMessageFactory->setFolderIdentity(MailCommon::Util::folderIdentity(mSettings.mItem));
     mMessageFactory->setMailingListAddresses(KMail::Util::mailingListsFromMessage(mSettings.mItem));
