@@ -27,15 +27,13 @@
 #include <TemplateParser/TemplateParserJob>
 
 NewMessageJob::NewMessageJob(QObject *parent)
-    : QObject(parent),
-      mMsg(nullptr)
+    : QObject(parent)
+    , mMsg(nullptr)
 {
-
 }
 
 NewMessageJob::~NewMessageJob()
 {
-
 }
 
 void NewMessageJob::start()
@@ -57,11 +55,11 @@ void NewMessageJob::start()
 
     mMsg->assemble();
 
-    mCollection = mNewMessageJobSettings.mFolder ? mNewMessageJobSettings.mFolder->collection() : Akonadi::Collection();
+    mCollection = mNewMessageJobSettings.mCurrentCollection;
     TemplateParser::TemplateParserJob *parser = new TemplateParser::TemplateParserJob(mMsg, TemplateParser::TemplateParserJob::NewMessage);
     connect(parser, &TemplateParser::TemplateParserJob::parsingDone, this, &NewMessageJob::slotOpenComposer);
     parser->setIdentityManager(KMKernel::self()->identityManager());
-    parser->process(mMsg, mCollection);
+    parser->process(mMsg, mCollection.id());
 }
 
 void NewMessageJob::slotOpenComposer()
