@@ -23,15 +23,11 @@
 #include <QFileDialog>
 #include <qpointer.h>
 #include <qtextdocumentwriter.h>
-#include <QUrl>
 #include <KLocalizedString>
 #include <QTextDocument>
 
 SaveAsFileJob::SaveAsFileJob(QObject *parent)
     : QObject(parent)
-    , mHtmlMode(false)
-    , mTextDocument(nullptr)
-    , mParentWidget(nullptr)
 {
 }
 
