@@ -29,7 +29,6 @@
 #include <kparts/readonlypart.h>
 
 #include <QWidget>
-#include <QPixmap>
 
 class KMMainWidget;
 
@@ -54,8 +53,8 @@ protected:
     void guiActivateEvent(KParts::GUIActivateEvent *e) override;
 
 private:
-    KMMainWidget *mainWidget;
-    QWidget *mParentWidget;
+    KMMainWidget *mainWidget = nullptr;
+    QWidget *mParentWidget = nullptr;
 };
 
 #endif
