@@ -2,7 +2,6 @@
 
 #ifndef KMCommands_h
 #define KMCommands_h
-#include "config-kmail.h"
 #include <MessageComposer/MessageFactoryNG>
 #include "MessageList/View"
 #include "mailcommon/searchpattern.h"
@@ -22,10 +21,15 @@ namespace Akonadi {
 class Tag;
 }
 
+namespace KPIM {
+class ProgressItem;
+}
+
 using Akonadi::MessageStatus;
 
 class QProgressDialog;
 class KMMainWidget;
+class KMReaderMainWin;
 
 template<typename T> class QSharedPointer;
 
@@ -137,7 +141,7 @@ protected:
 
 private:
     // ProgressDialog for transferring messages
-    QWeakPointer<QProgressDialog> mProgressDialog;
+    QPointer<QProgressDialog> mProgressDialog;
     //Currently only one async command allowed at a time
     static int mCountJobs;
     int mCountMsgs;
@@ -145,7 +149,7 @@ private:
     bool mDeletesItself : 1;
     bool mEmitsCompletedItself : 1;
 
-    QWidget *mParent;
+    QWidget *mParent = nullptr;
     Akonadi::Item::List mMsgList;
     Akonadi::ItemFetchScope mFetchScope;
 };
@@ -230,7 +234,7 @@ private Q_SLOTS:
     void slotDeleteItem(KJob *job);
 private:
     Result execute() override;
-    bool mDeleteFromSource;
+    bool mDeleteFromSource = false;
 };
 
 class KMEditMessageCommand : public KMCommand
@@ -285,9 +289,9 @@ private:
     static const int MAX_CHUNK_SIZE = 64 * 1024;
     QUrl mUrl;
     QString mMsgString;
-    KIO::TransferJob *mJob;
+    KIO::TransferJob *mJob = nullptr;
     const QString mEncoding;
-    KMMainWidget *mMainWidget;
+    KMMainWidget *mMainWidget = nullptr;
 };
 
 class KMSaveAttachmentsCommand : public KMCommand
@@ -307,7 +311,7 @@ public:
 
 private:
     Result execute() override;
-    MessageViewer::Viewer *mViewer;
+    MessageViewer::Viewer *mViewer = nullptr;
 };
 
 class KMReplyCommand : public KMCommand
@@ -323,7 +327,7 @@ private:
     QString mSelection;
     QString mTemplate;
     MessageComposer::ReplyStrategy m_replyStrategy;
-    bool mNoQuote;
+    bool mNoQuote = false;
 };
 
 class KMForwardCommand : public KMCommand
@@ -387,14 +391,14 @@ public:
 private:
     Result execute() override;
 
-    MessageViewer::HeaderStylePlugin *mHeaderStylePlugin;
-    const MimeTreeParser::AttachmentStrategy *mAttachmentStrategy;
+    MessageViewer::HeaderStylePlugin *mHeaderStylePlugin = nullptr;
+    const MimeTreeParser::AttachmentStrategy *mAttachmentStrategy = nullptr;
     QFont mOverrideFont;
     QString mEncoding;
     MessageViewer::Viewer::DisplayFormatMessage mFormat;
-    bool mHtmlLoadExtOverride;
-    bool mUseFixedFont;
-    bool mPrintPreview;
+    bool mHtmlLoadExtOverride = false;
+    bool mUseFixedFont = false;
+    bool mPrintPreview = false;
 };
 
 class KMSetStatusCommand : public KMCommand
@@ -411,7 +415,7 @@ protected Q_SLOTS:
 private:
     Result execute() override;
     MessageStatus mStatus;
-    bool mInvertMark;
+    bool mInvertMark = false;
 };
 
 /** This command is used to set or toggle a tag for a list of messages. If toggle is
@@ -468,7 +472,7 @@ public Q_SLOTS:
 
 private:
     QString mFilterId;
-    KMMainWidget *mMainWidget;
+    KMMainWidget *mMainWidget = nullptr;
 };
 
 class KMMailingListFilterCommand : public KMCommand
@@ -498,9 +502,23 @@ private:
     Akonadi::Collection mDestFolder;
 };
 
-namespace KPIM {
-class ProgressItem;
-}
+class KMCopyDecryptedCommand : public KMCommand
+{
+    Q_OBJECT
+public:
+    KMCopyDecryptedCommand(const Akonadi::Collection &destFolder, const Akonadi::Item::List &msgList);
+    KMCopyDecryptedCommand(const Akonadi::Collection &destFolder, const Akonadi::Item &msg);
+
+protected Q_SLOTS:
+    void slotAppendResult(KJob *job);
+
+private:
+    Result execute() override;
+
+    Akonadi::Collection mDestFolder;
+    QList<KJob *> mPendingJobs;
+};
+
 class KMMoveCommand : public KMCommand
 {
     Q_OBJECT
@@ -535,7 +553,7 @@ private:
     void completeMove(Result result);
 
     Akonadi::Collection mDestFolder;
-    KPIM::ProgressItem *mProgressItem;
+    KPIM::ProgressItem *mProgressItem = nullptr;
     MessageList::Core::MessageItemSetReference mRef;
 };
 
@@ -578,15 +596,19 @@ class KMFetchMessageCommand : public KMCommand
 {
     Q_OBJECT
 public:
-    explicit KMFetchMessageCommand(QWidget *parent, const Akonadi::Item &item);
+    explicit KMFetchMessageCommand(QWidget *parent, const Akonadi::Item &item, MessageViewer::Viewer *viewer, KMReaderMainWin *win = nullptr);
 
     Akonadi::Item item() const;
 
+    KMReaderMainWin *readerMainWin() const;
+
 private:
     Akonadi::ItemFetchJob *createFetchJob(const Akonadi::Item::List &items) override;
     Result execute() override;
 
     Akonadi::Item mItem;
+    MessageViewer::Viewer *mViewer = nullptr;
+    KMReaderMainWin *mReaderMainWin = nullptr;
 };
 
 #endif /*KMCommands_h*/
