@@ -74,10 +74,10 @@ class FolderSettings;
 class FolderCollectionMonitor;
 class JobScheduler;
 class KMFilterDialog;
+class MailCommonSettings;
 }
 
 class QTimer;
-class KMMainWin;
 class KMainWindow;
 class KMMainWidget;
 class ConfigureDialog;
@@ -152,7 +152,7 @@ public Q_SLOTS:
     */
     Q_SCRIPTABLE void resumeNetworkJobs();
 
-    Q_SCRIPTABLE QStringList accounts();
+    Q_SCRIPTABLE QStringList accounts() const;
 
     Q_SCRIPTABLE void makeResourceOnline(MessageViewer::Viewer::ResourceOnlineMode mode);
 
@@ -348,10 +348,7 @@ public:
     /** return the pointer to the identity manager */
     KIdentityManagement::IdentityManager *identityManager() override;
 
-    MailCommon::JobScheduler *jobScheduler() const override
-    {
-        return mJobScheduler;
-    }
+    MailCommon::JobScheduler *jobScheduler() const override;
 
     /** Expire all folders, used for the gui action */
     void expireAllFoldersNow();
@@ -367,10 +364,7 @@ public:
     */
     bool haveSystemTrayApplet() const;
 
-    QTextCodec *networkCodec() const
-    {
-        return mNetCodec;
-    }
+    QTextCodec *networkCodec() const;
 
     /** returns a reference to the first Mainwin or a temporary Mainwin */
     KMainWindow *mainWin();
@@ -383,6 +377,12 @@ public:
     * is empty at startup.
     */
     Akonadi::Collection::List allFolders() const;
+
+    /**
+     * Includes all subfolders of @p col, including the @p col itself.
+     */
+    Akonadi::Collection::List subfolders(const Akonadi::Collection &col) const;
+
     //
     void selectCollectionFromId(Akonadi::Collection::Id id);
 
@@ -415,10 +415,13 @@ public:
     void toggleSystemTray();
     FolderArchiveManager *folderArchiveManager() const;
 
-    bool allowToDebugBalooSupport() const;
+    bool allowToDebug() const;
 
     Akonadi::Search::PIM::IndexedItems *indexedItems() const;
 
+    void cleanupTemporaryFiles();
+    MailCommon::MailCommonSettings *mailCommonSettings() const;
+
 protected:
     void agentInstanceBroken(const Akonadi::AgentInstance &instance);
 
@@ -494,46 +497,45 @@ private:
     void openReader(bool onlyCheck);
     QSharedPointer<MailCommon::FolderSettings> currentFolderCollection();
 
-    UndoStack *the_undoStack;
-    MessageComposer::AkonadiSender *the_msgSender;
+    UndoStack *the_undoStack = nullptr;
+    MessageComposer::AkonadiSender *the_msgSender = nullptr;
     /** previous KMail version. If different from current,
       the user has just updated. read from config */
     QString the_previousVersion;
     /** is this the first start?  read from config */
-    bool the_firstStart;
+    bool the_firstStart = false;
     /** are we going down? set from here */
-    bool the_shuttingDown;
+    bool the_shuttingDown = false;
     /** true unles kmail is closed by session management */
-    bool the_firstInstance;
+    bool the_firstInstance = false;
 
     KSharedConfig::Ptr mConfig;
-    QTextCodec *mNetCodec;
+    QTextCodec *mNetCodec = nullptr;
     QString mXmlGuiInstance;
-    ConfigureDialog *mConfigureDialog;
+    ConfigureDialog *mConfigureDialog = nullptr;
 
-    QTimer *mBackgroundTasksTimer;
-    MailCommon::JobScheduler *mJobScheduler;
-    // temporary mainwin
-    KMMainWin *mWin;
-    MailServiceImpl *mMailService;
+    QTimer *mBackgroundTasksTimer = nullptr;
+    MailCommon::JobScheduler *mJobScheduler = nullptr;
+    MailServiceImpl *mMailService = nullptr;
 
-    bool mSystemNetworkStatus;
+    bool mSystemNetworkStatus = true;
 
-    KMail::KMSystemTray *mSystemTray;
+    KMail::KMSystemTray *mSystemTray = nullptr;
     QHash<QString, KPIM::ProgressItem::CryptoStatus> mResourceCryptoSettingCache;
-    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
-    Akonadi::EntityTreeModel *mEntityTreeModel;
-    Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
+    MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor = nullptr;
+    Akonadi::EntityTreeModel *mEntityTreeModel = nullptr;
+    Akonadi::EntityMimeTypeFilterModel *mCollectionModel = nullptr;
 
     /// List of Akonadi resources that are currently being checked.
     QStringList mResourcesBeingChecked;
 
     QPointer<MailCommon::KMFilterDialog> mFilterEditDialog;
-    PimCommon::AutoCorrection *mAutoCorrection;
-    FolderArchiveManager *mFolderArchiveManager;
-    CheckIndexingManager *mCheckIndexingManager;
-    Akonadi::Search::PIM::IndexedItems *mIndexedItems;
-    bool mDebugBaloo;
+    PimCommon::AutoCorrection *mAutoCorrection = nullptr;
+    FolderArchiveManager *mFolderArchiveManager = nullptr;
+    CheckIndexingManager *mCheckIndexingManager = nullptr;
+    Akonadi::Search::PIM::IndexedItems *mIndexedItems = nullptr;
+    MailCommon::MailCommonSettings *mMailCommonSettings = nullptr;
+    bool mDebug = false;
 };
 
 #endif // _KMKERNEL_H
