@@ -28,8 +28,8 @@
 #include "followupreminderinterface.h"
 #include "MailCommon/FilterManager"
 
-#include <QtDBus/QDBusInterface>
-#include <QtDBus/QDBusReply>
+#include <QDBusInterface>
+#include <QDBusReply>
 #include <QProcess>
 #include "kmail_debug.h"
 #include <QStandardPaths>
@@ -97,18 +97,9 @@ void KMLaunchExternalComponent::slotStartCertManager()
     }
 }
 
-void KMLaunchExternalComponent::slotStartWatchGnuPG()
-{
-    if (!QProcess::startDetached(QStringLiteral("kwatchgnupg"))) {
-        KMessageBox::error(mParentWidget, i18n("Could not start GnuPG LogViewer (kwatchgnupg); "
-                                               "please check your installation."),
-                           i18n("KMail Error"));
-    }
-}
-
 void KMLaunchExternalComponent::slotImportWizard()
 {
-    const QString path = QStandardPaths::findExecutable(QStringLiteral("importwizard"));
+    const QString path = QStandardPaths::findExecutable(QStringLiteral("akonadiimportwizard"));
     if (!QProcess::startDetached(path)) {
         KMessageBox::error(mParentWidget, i18n("Could not start the import wizard. "
                                                "Please make sure you have ImportWizard properly installed."),
@@ -126,7 +117,7 @@ void KMLaunchExternalComponent::slotExportData()
     }
 }
 
-void KMLaunchExternalComponent::slotAddrBook()
+void KMLaunchExternalComponent::slotRunAddressBook()
 {
     KRun::runCommand(QStringLiteral("kaddressbook"), mParentWidget->window());
 }
@@ -134,7 +125,7 @@ void KMLaunchExternalComponent::slotAddrBook()
 void KMLaunchExternalComponent::slotImport()
 {
     const QStringList lst = {QStringLiteral("--mode"), QStringLiteral("manual")};
-    const QString path = QStandardPaths::findExecutable(QStringLiteral("importwizard"));
+    const QString path = QStandardPaths::findExecutable(QStringLiteral("akonadiimportwizard"));
     if (!QProcess::startDetached(path, lst)) {
         KMessageBox::error(mParentWidget, i18n("Could not start the ImportWizard. "
                                                "Please make sure you have ImportWizard properly installed."),
