@@ -27,13 +27,11 @@
 #include "tag/tagactionmanager.h"
 
 #include <QTimer>
-#include <QAction>
 #include <QStatusBar>
 #include <QApplication>
 
 #include <KConfigGui>
 #include <QMenuBar>
-#include <KToggleAction>
 #include <KConfigGui>
 #include <KLocalizedString>
 #include <kedittoolbar.h>
@@ -49,7 +47,6 @@
 
 KMMainWin::KMMainWin(QWidget *)
     : KXmlGuiWindow(nullptr)
-    , mReallyClose(false)
 {
     setObjectName(QStringLiteral("kmail-mainwindow#"));
     // Set this to be the group leader for all subdialogs - this means
@@ -81,11 +78,11 @@ KMMainWin::KMMainWin(QWidget *)
     //must be after createGUI, otherwise e.g toolbar settings are not loaded
     applyMainWindowSettings(KMKernel::self()->config()->group("Main Window"));
 
-    connect(KPIM::BroadcastStatus::instance(), SIGNAL(statusMsg(QString)),
-            this, SLOT(displayStatusMsg(QString)));
+    connect(KPIM::BroadcastStatus::instance(), &KPIM::BroadcastStatus::statusMsg,
+            this, &KMMainWin::displayStatusMessage);
 
-    connect(mKMMainWidget, SIGNAL(captionChangeRequest(QString)),
-            SLOT(setCaption(QString)));
+    connect(mKMMainWidget, &KMMainWidget::captionChangeRequest,
+            this, QOverload<const QString &>::of(&KMainWindow::setCaption));
 
     mKMMainWidget->updateQuickSearchLineText();
     mHideMenuBarAction->setChecked(KMailSettings::self()->showMenuBar());
@@ -104,7 +101,7 @@ KMMainWidget *KMMainWin::mainKMWidget() const
     return mKMMainWidget;
 }
 
-void KMMainWin::displayStatusMsg(const QString &aText)
+void KMMainWin::displayStatusMessage(const QString &aText)
 {
     if (!statusBar() || !mProgressBar->littleProgress()) {
         return;
@@ -148,10 +145,11 @@ void KMMainWin::slotEditToolbars()
 {
     KConfigGroup grp = KMKernel::self()->config()->group("Main Window");
     saveMainWindowSettings(grp);
-    KEditToolBar dlg(guiFactory(), this);
-    connect(&dlg, &KEditToolBar::newToolBarConfig, this, &KMMainWin::slotUpdateGui);
+    QPointer<KEditToolBar> dlg = new KEditToolBar(guiFactory(), this);
+    connect(dlg.data(), &KEditToolBar::newToolBarConfig, this, &KMMainWin::slotUpdateGui);
 
-    dlg.exec();
+    dlg->exec();
+    delete dlg;
 }
 
 void KMMainWin::slotUpdateGui()
