@@ -47,7 +47,7 @@ public:
     bool restoreDockedState(int number);
 
 public Q_SLOTS:
-    void displayStatusMsg(const QString &);
+    void displayStatusMessage(const QString &);
     void slotEditToolbars();
     void slotUpdateGui();
     void setupStatusBar();
@@ -62,16 +62,14 @@ protected:
 protected Q_SLOTS:
     void slotQuit();
 
-private Q_SLOTS:
-    void slotToggleMenubar(bool dontShowWarning = false);
-    void slotConfigureShortcuts();
-
 private:
-    KPIM::ProgressStatusBarWidget *mProgressBar;
-    KMMainWidget *mKMMainWidget;
-    KToggleAction *mHideMenuBarAction;
-    bool mReallyClose;
-    QLabel *mMessageLabel;
+    void slotConfigureShortcuts();
+    void slotToggleMenubar(bool dontShowWarning);
+    KPIM::ProgressStatusBarWidget *mProgressBar = nullptr;
+    KMMainWidget *mKMMainWidget = nullptr;
+    KToggleAction *mHideMenuBarAction = nullptr;
+    QLabel *mMessageLabel = nullptr;
+    bool mReallyClose = false;
 };
 
 #endif
