@@ -40,6 +40,7 @@ public:
 
     void setUseFixedFont(bool useFixedFont);
 
+    MessageViewer::Viewer *viewer() const;
     /**
     * take ownership of and show @param msg
     *
@@ -53,12 +54,7 @@ public:
     void showMessage(const QString &encoding, const KMime::Message::Ptr &message);
     void showMessagePopup(const Akonadi::Item &msg, const QUrl &aUrl, const QUrl &imageUrl, const QPoint &aPoint, bool contactAlreadyExists, bool uniqueContactFound,
                           const WebEngineViewer::WebHitTestResult &result);
-
-private Q_SLOTS:
-    void slotMessagePopup(const Akonadi::Item &aMsg, const WebEngineViewer::WebHitTestResult &result, const QPoint &aPoint);
-    void slotContactSearchJobForMessagePopupDone(KJob *);
-    void slotExecuteMailAction(MessageViewer::Viewer::MailAction action);
-    void slotTrashMessage();
+public Q_SLOTS:
     void slotForwardInlineMsg();
     void slotForwardAttachedMessage();
     void slotRedirectMessage();
@@ -66,6 +62,11 @@ private Q_SLOTS:
     void slotCustomReplyAllToMsg(const QString &tmpl);
     void slotCustomForwardMsg(const QString &tmpl);
 
+private:
+    void slotMessagePopup(const Akonadi::Item &aMsg, const WebEngineViewer::WebHitTestResult &result, const QPoint &aPoint);
+    void slotContactSearchJobForMessagePopupDone(KJob *);
+    void slotTrashMessage();
+
     void slotEditToolbars();
     void slotConfigChanged();
     void slotUpdateToolbars();
@@ -78,7 +79,7 @@ private Q_SLOTS:
     void slotMoveItem(QAction *action);
 
     void slotShowMessageStatusBar(const QString &msg);
-private:
+
     void copyOrMoveItem(const Akonadi::Collection &collection, bool move);
     Akonadi::Collection parentCollection() const;
     void initKMReaderMainWin();
@@ -86,12 +87,13 @@ private:
     QAction *copyActionMenu(QMenu *menu);
     QAction *moveActionMenu(QMenu *menu);
 
-    KMReaderWin *mReaderWin;
+    Akonadi::Collection mParentCollection;
     Akonadi::Item mMsg;
     // a few actions duplicated from kmmainwidget
-    QAction *mTrashAction, *mSaveAtmAction;
-    KMail::MessageActions *mMsgActions;
-    Akonadi::Collection mParentCollection;
+    QAction *mTrashAction = nullptr;
+    QAction *mSaveAtmAction = nullptr;
+    KMail::MessageActions *mMsgActions = nullptr;
+    KMReaderWin *mReaderWin = nullptr;
 };
 
 #endif /*KMReaderMainWin_h*/
