@@ -61,7 +61,6 @@ using namespace MessageViewer;
 
 #include <KIO/JobUiDelegate>
 
-
 #include <Akonadi/Contact/ContactEditorDialog>
 
 #include "kmail_debug.h"
@@ -89,27 +88,19 @@ KMReaderWin::KMReaderWin(QWidget *aParent, QWidget *mainWindow, KActionCollectio
     : QWidget(aParent)
     , mMainWindow(mainWindow)
     , mActionCollection(actionCollection)
-    , mMailToComposeAction(nullptr)
-    , mMailToReplyAction(nullptr)
-    , mMailToForwardAction(nullptr)
-    , mAddAddrBookAction(nullptr)
-    , mOpenAddrBookAction(nullptr)
-    , mUrlSaveAsAction(nullptr)
-    , mAddBookmarksAction(nullptr)
-    , mAddEmailToExistingContactAction(nullptr)
 {
     createActions();
     QVBoxLayout *vlay = new QVBoxLayout(this);
     vlay->setContentsMargins(0, 4, 0, 0);
     mViewer = new Viewer(this, mainWindow, mActionCollection);
-    connect(mViewer, SIGNAL(urlClicked(Akonadi::Item,QUrl)), this, SLOT(slotUrlClicked(Akonadi::Item,QUrl)));
+    connect(mViewer, QOverload<const Akonadi::Item &, const QUrl &>::of(&Viewer::urlClicked), this, &KMReaderWin::slotUrlClicked);
     connect(mViewer, &Viewer::requestConfigSync, kmkernel, &KMKernel::slotRequestConfigSync, Qt::QueuedConnection);   // happens anyway on shutdown, so we can skip it there with using a queued connection
     connect(mViewer, &Viewer::makeResourceOnline, kmkernel, &KMKernel::makeResourceOnline);
     connect(mViewer, &MessageViewer::Viewer::showReader, this, &KMReaderWin::slotShowReader);
     connect(mViewer, &MessageViewer::Viewer::showMessage, this, &KMReaderWin::slotShowMessage);
     connect(mViewer, &MessageViewer::Viewer::showStatusBarMessage, this, &KMReaderWin::showStatusBarMessage);
     connect(mViewer, &MessageViewer::Viewer::printingFinished, this, &KMReaderWin::slotPrintingFinished);
-    connect(mViewer, SIGNAL(deleteMessage(Akonadi::Item)), this, SLOT(slotDeleteMessage(Akonadi::Item)));
+    connect(mViewer, QOverload<const Akonadi::Item &>::of(&Viewer::deleteMessage), this, &KMReaderWin::slotDeleteMessage);
 
     mViewer->addMessageLoadedHandler(new MessageViewer::MarkMessageReadHandler(this));
     mViewer->addMessageLoadedHandler(new MailCommon::SendMdnHandler(kmkernel, this));
@@ -222,7 +213,7 @@ void KMReaderWin::setUseFixedFont(bool useFixedFont)
     mViewer->setUseFixedFont(useFixedFont);
 }
 
-Viewer *KMReaderWin::viewer()
+Viewer *KMReaderWin::viewer() const
 {
     return mViewer;
 }
@@ -361,7 +352,7 @@ void KMReaderWin::displayAboutPage()
     }
     data[QStringLiteral("importantChanges")] = changes;
 
-    displaySplashPage(QStringLiteral("introduction_kmail.html"), data);
+    displaySplashPage(QStringLiteral(":/about/introduction_kmail.html"), data);
 }
 
 void KMReaderWin::slotFind()
@@ -421,7 +412,7 @@ Akonadi::Item KMReaderWin::message() const
     return mViewer->messageItem();
 }
 
-QWidget *KMReaderWin::mainWindow()
+QWidget *KMReaderWin::mainWindow() const
 {
     return mMainWindow;
 }
@@ -692,8 +683,8 @@ void KMReaderWin::update(bool force)
 void KMReaderWin::slotUrlClicked(const Akonadi::Item &item, const QUrl &url)
 {
     if (item.isValid() && item.parentCollection().isValid()) {
-        QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(
-            MailCommon::Util::updatedCollection(item.parentCollection()), false);
+        const auto col = CommonKernel->collectionFromId(item.parentCollection().id());
+        QSharedPointer<FolderSettings> fd = FolderSettings::forCollection(col, false);
         KMail::Util::handleClickedURL(url, fd, item.parentCollection());
         return;
     }
@@ -752,8 +743,8 @@ void KMReaderWin::slotPrintComposeResult(KJob *job)
     if (composer->error() == ::MessageComposer::Composer::NoError) {
         Q_ASSERT(composer->resultMessages().size() == 1);
         Akonadi::Item printItem;
-        printItem.setPayload<KMime::Message::Ptr>(composer->resultMessages().first());
-        Akonadi::MessageFlags::copyMessageFlags(*(composer->resultMessages().first()), printItem);
+        printItem.setPayload<KMime::Message::Ptr>(composer->resultMessages().constFirst());
+        Akonadi::MessageFlags::copyMessageFlags(*(composer->resultMessages().constFirst()), printItem);
         const bool useFixedFont = MessageViewer::MessageViewerSettings::self()->useFixedFont();
         const QString overrideEncoding = MessageCore::MessageCoreSettings::self()->overrideCharacterEncoding();
 
