@@ -122,7 +122,7 @@ public:
 
     bool isFixedFont() const;
     void setUseFixedFont(bool useFixedFont);
-    MessageViewer::Viewer *viewer();
+    MessageViewer::Viewer *viewer() const;
     KToggleAction *toggleFixFontAction() const;
     QAction *mailToComposeAction() const;
     QAction *mailToReplyAction() const;
@@ -153,7 +153,7 @@ public:
 
     Akonadi::Item message() const;
 
-    QWidget *mainWindow();
+    QWidget *mainWindow() const;
 
     /** Enforce message decryption. */
     void setDecryptMessageOverwrite(bool overwrite = true);
@@ -173,16 +173,12 @@ public:
     QList<QAction *> interceptorUrlActions(const WebEngineViewer::WebHitTestResult &result) const;
 
     void setPrintElementBackground(bool printElementBackground);
+    /** Force update even if message is the same */
+    void clearCache();
 Q_SIGNALS:
-    /** Emitted after parsing of a message to have it stored
-      in unencrypted state in it's folder. */
-    void replaceMsgByUnencryptedVersion();
-
     void showStatusBarMessage(const QString &message);
 
 public Q_SLOTS:
-    /** Force update even if message is the same */
-    void clearCache();
 
     /** The user selected "Find" from the menu. */
     void slotFind();
@@ -224,26 +220,26 @@ private:
 private:
     KContacts::Addressee mSearchedAddress;
     Akonadi::Item mSearchedContact;
-    QWidget *mMainWindow;
-    KActionCollection *mActionCollection;
+    QWidget *mMainWindow = nullptr;
+    KActionCollection *mActionCollection = nullptr;
 
-    QAction *mMailToComposeAction;
-    QAction *mMailToReplyAction;
-    QAction *mMailToForwardAction;
-    QAction *mAddAddrBookAction;
-    QAction *mOpenAddrBookAction;
-    QAction *mUrlSaveAsAction;
-    QAction *mAddBookmarksAction;
-    QAction *mImageUrlSaveAsAction;
-    QAction *mEditContactAction;
-    QAction *mViewAsHtml;
-    QAction *mLoadExternalReference;
-    QAction *mShareImage;
-    QAction *mAddEmailToExistingContactAction;
+    QAction *mMailToComposeAction = nullptr;
+    QAction *mMailToReplyAction = nullptr;
+    QAction *mMailToForwardAction = nullptr;
+    QAction *mAddAddrBookAction = nullptr;
+    QAction *mOpenAddrBookAction = nullptr;
+    QAction *mUrlSaveAsAction = nullptr;
+    QAction *mAddBookmarksAction = nullptr;
+    QAction *mImageUrlSaveAsAction = nullptr;
+    QAction *mEditContactAction = nullptr;
+    QAction *mViewAsHtml = nullptr;
+    QAction *mLoadExternalReference = nullptr;
+    QAction *mShareImage = nullptr;
+    QAction *mAddEmailToExistingContactAction = nullptr;
 
-    QMenu *mViewHtmlOptions;
+    QMenu *mViewHtmlOptions = nullptr;
 
-    MessageViewer::Viewer *mViewer;
+    MessageViewer::Viewer *mViewer = nullptr;
 };
 
 #endif
