@@ -32,10 +32,7 @@
 #include <QMenu>
 #include <KLocalizedString>
 #include <QAction>
-#include <KActionMenu>
 #include "widgets/kactionmenutransport.h"
-#include <KActionCollection>
-#include <QPainter>
 
 #include <AkonadiCore/ChangeRecorder>
 #include <AkonadiCore/EntityTreeModel>
@@ -58,12 +55,6 @@ using namespace KMail;
 
 KMSystemTray::KMSystemTray(QObject *parent)
     : KStatusNotifierItem(parent)
-    , mIcon(QIcon::fromTheme(QStringLiteral("mail-mark-unread-new")))
-    , mDesktopOfMainWin(0)
-    , mCount(0)
-    , mIconNotificationsEnabled(true)
-    , mNewMessagesPopup(nullptr)
-    , mSendQueued(nullptr)
 {
     qCDebug(KMAIL_LOG) << "Initting systray";
     setToolTipTitle(i18n("KMail"));
@@ -106,7 +97,7 @@ bool KMSystemTray::buildPopupMenu()
     contextMenu()->clear();
     contextMenu()->setIcon(qApp->windowIcon());
     contextMenu()->setTitle(i18n("KMail"));
-    QAction *action;
+    QAction *action = nullptr;
     if ((action = mainWidget->action(QStringLiteral("check_mail")))) {
         contextMenu()->addAction(action);
     }
@@ -148,7 +139,7 @@ void KMSystemTray::slotGeneralFontChanged()
 
 /**
  * Update the count of unread messages.  If there are unread messages,
- * overlay the count on top of a transparent version of the KMail icon.
+ * show the "unread new mail" KMail icon.
  * If there is no unread mail, restore the normal KMail icon.
  */
 void KMSystemTray::updateCount()
@@ -156,7 +147,7 @@ void KMSystemTray::updateCount()
     if (mCount == 0) {
         setIconByName(QStringLiteral("kmail"));
     } else {
-        setIconByPixmap(mIcon);
+        setIconByName(QStringLiteral("mail-mark-unread-new"));
     }
 }
 
