@@ -49,18 +49,16 @@ public:
     void save() override;
     void defaults() override;
 
-private Q_SLOTS:
-    void modified();
-
 private:
+    void modified();
     void initGUI();
     void initFolders();
     void loadFolders();
     void storeFolders();
 
-    PimCommon::CheckedCollectionWidget *mCheckedCollectionWidget;
-    QCheckBox *mFullPath;
-    KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState;
+    PimCommon::CheckedCollectionWidget *mCheckedCollectionWidget = nullptr;
+    QCheckBox *mFullPath = nullptr;
+    KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mModelState = nullptr;
 };
 
 #endif
