@@ -90,12 +90,17 @@ SummaryWidget::SummaryWidget(KontactInterface::Plugin *plugin, QWidget *parent)
         = new KViewStateMaintainer<Akonadi::ETMViewStateSaver>(_config->group("CheckState"), this);
     mModelState->setSelectionModel(mSelectionModel);
 
-    connect(mChangeRecorder, static_cast<void (Akonadi::ChangeRecorder::*)(const Akonadi::Collection &)>(&Akonadi::ChangeRecorder::collectionChanged), this, &SummaryWidget::slotCollectionChanged);
+    connect(mChangeRecorder, QOverload<const Akonadi::Collection &>::of(&Akonadi::ChangeRecorder::collectionChanged), this, &SummaryWidget::slotCollectionChanged);
     connect(mChangeRecorder, &Akonadi::ChangeRecorder::collectionRemoved, this, &SummaryWidget::slotCollectionChanged);
     connect(mChangeRecorder, &Akonadi::ChangeRecorder::collectionStatisticsChanged, this, &SummaryWidget::slotCollectionChanged);
     QTimer::singleShot(0, this, &SummaryWidget::slotUpdateFolderList);
 }
 
+int SummaryWidget::summaryHeight() const
+{
+    return 1;
+}
+
 void SummaryWidget::slotCollectionChanged()
 {
     QTimer::singleShot(0, this, &SummaryWidget::slotUpdateFolderList);
@@ -134,7 +139,7 @@ void SummaryWidget::displayModel(const QModelIndex &parent, int &counter, const
             const Akonadi::CollectionStatistics stats = col.statistics();
             if (((stats.unreadCount()) != Q_INT64_C(0)) && showCollection) {
                 // Collection Name.
-                KUrlLabel *urlLabel;
+                KUrlLabel *urlLabel = nullptr;
 
                 if (showFolderPaths) {
                     // Construct the full path string.
@@ -160,7 +165,7 @@ void SummaryWidget::displayModel(const QModelIndex &parent, int &counter, const
                                           stats.count(),
                                           stats.unreadCount()));
 
-                connect(urlLabel, static_cast<void (KUrlLabel::*)(const QString &)>(&KUrlLabel::leftClickedUrl), this, &SummaryWidget::selectFolder);
+                connect(urlLabel, QOverload<const QString &>::of(&KUrlLabel::leftClickedUrl), this, &SummaryWidget::selectFolder);
 
                 // Read and unread count.
                 QLabel *label = new QLabel(i18nc("%1: number of unread messages "
