@@ -106,7 +106,7 @@ void ManageShowCollectionProperties::showCollectionProperties(const QString &pag
             sync->setProperty("progressItem", QVariant::fromValue(progressItem));
             connect(sync, &KJob::result,
                     this, &ManageShowCollectionProperties::slotCollectionPropertiesContinued);
-            connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem *)),
+            connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
                     sync, SLOT(kill()));
             connect(progressItem.data(), &KPIM::ProgressItem::progressItemCanceled,
                     KPIM::ProgressManager::instance(), &KPIM::ProgressManager::slotStandardCancelHandler);
@@ -135,7 +135,7 @@ void ManageShowCollectionProperties::slotCollectionPropertiesContinued(KJob *job
         pageToShow = sync->property("pageToShow").toString();
         progressItem = sync->property("progressItem").value< QPointer<KPIM::ProgressItem> >();
         if (progressItem) {
-            disconnect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem *)),
+            disconnect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
                        sync, SLOT(kill()));
         } else {
             // progressItem does not exist anymore, operation has been canceled
@@ -158,13 +158,13 @@ void ManageShowCollectionProperties::showCollectionPropertiesContinued(const QSt
 
     Akonadi::CollectionFetchJob *fetch = new Akonadi::CollectionFetchJob(mMainWidget->currentCollection(),
                                                                          Akonadi::CollectionFetchJob::Base);
-    connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem *)), fetch, SLOT(kill()));
+    connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)), fetch, SLOT(kill()));
     fetch->fetchScope().setIncludeStatistics(true);
     fetch->setProperty("pageToShow", pageToShow);
     fetch->setProperty("progressItem", QVariant::fromValue(progressItem));
     connect(fetch, &KJob::result,
             this, &ManageShowCollectionProperties::slotCollectionPropertiesFinished);
-    connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem *)),
+    connect(progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)),
             fetch, SLOT(kill()));
 }
 
@@ -190,7 +190,7 @@ void ManageShowCollectionProperties::slotCollectionPropertiesFinished(KJob *job)
         return;
     }
 
-    const Akonadi::Collection collection = fetch->collections().first();
+    const Akonadi::Collection collection = fetch->collections().constFirst();
 
     QPointer<Akonadi::CollectionPropertiesDialog> dlg = new Akonadi::CollectionPropertiesDialog(collection, mPages, mMainWidget);
     dlg->setWindowTitle(i18nc("@title:window", "Properties of Folder %1", collection.name()));
