@@ -53,7 +53,6 @@
 #include <KRun>
 #include <QMenu>
 #include <KUriFilter>
-#include <KStringHandler>
 #include <QIcon>
 
 #include <QVariant>
@@ -67,12 +66,6 @@ using namespace KMail;
 MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     : QObject(parent)
     , mParent(parent)
-    , mMessageView(nullptr)
-    , mRedirectAction(nullptr)
-    , mPrintPreviewAction(nullptr)
-    , mCustomTemplatesMenu(nullptr)
-    , mAddFollowupReminderAction(nullptr)
-    , mDebugBalooAction(nullptr)
 {
     mWebShortcutMenuManager = new KIO::KUriFilterSearchProviderActions(this);
     mReplyActionMenu = new KActionMenu(QIcon::fromTheme(QStringLiteral("mail-reply-sender")), i18nc("Message->", "&Reply"), this);
@@ -132,11 +125,6 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
         mStatusMenu->addAction(action);
     }
 
-    mEditAction = new QAction(QIcon::fromTheme(QStringLiteral("accessories-text-editor")), i18n("&Edit Message"), this);
-    ac->addAction(QStringLiteral("edit"), mEditAction);
-    connect(mEditAction, &QAction::triggered, this, &MessageActions::editCurrentMessage);
-    ac->setDefaultShortcut(mEditAction, Qt::Key_T);
-
     mAnnotateAction = new QAction(QIcon::fromTheme(QStringLiteral("view-pim-notes")), i18n("Add Note..."), this);
     ac->addAction(QStringLiteral("annotate"), mAnnotateAction);
     connect(mAnnotateAction, &QAction::triggered, this, &MessageActions::annotateMessage);
@@ -193,9 +181,9 @@ MessageActions::MessageActions(KActionCollection *ac, QWidget *parent)
     replyMenu()->addAction(mCustomTemplatesMenu->replyActionMenu());
     replyMenu()->addAction(mCustomTemplatesMenu->replyAllActionMenu());
 
-    //Don't translate it. Shown only when we set env variable KDEPIM_BALOO_DEBUG
-    mDebugBalooAction = new QAction(QStringLiteral("Debug Baloo..."), this);
-    connect(mDebugBalooAction, &QAction::triggered, this, &MessageActions::slotDebugBaloo);
+    //Don't translate it. Shown only when we set env variable AKONADI_SEARCH_DEBUG
+    mDebugAkonadiSearchAction = new QAction(QStringLiteral("Debug Akonadi Search..."), this);
+    connect(mDebugAkonadiSearchAction, &QAction::triggered, this, &MessageActions::slotDebugAkonadiSearch);
 
     mAddFollowupReminderAction = new QAction(i18n("Add Followup Reminder..."), this);
     ac->addAction(QStringLiteral("message_followup_reminder"), mAddFollowupReminderAction);
@@ -269,11 +257,6 @@ KActionMenu *MessageActions::forwardMenu() const
     return mForwardActionMenu;
 }
 
-QAction *MessageActions::editAction() const
-{
-    return mEditAction;
-}
-
 QAction *MessageActions::annotateAction() const
 {
     return mAnnotateAction;
@@ -337,7 +320,7 @@ void MessageActions::updateActions()
         }
     }
 
-    const bool multiVisible = mVisibleItems.count() > 0 || mCurrentItem.isValid();
+    const bool multiVisible = !mVisibleItems.isEmpty() || mCurrentItem.isValid();
     const bool uniqItem = (itemValid || hasPayload) && (mVisibleItems.count() <= 1);
     mReplyActionMenu->setEnabled(hasPayload);
     mReplyAction->setEnabled(hasPayload);
@@ -368,7 +351,6 @@ void MessageActions::updateActions()
             connect(job, &Akonadi::ItemFetchJob::result, this, &MessageActions::slotUpdateActionsFetchDone);
         }
     }
-    mEditAction->setEnabled(uniqItem);
 }
 
 void MessageActions::slotUpdateActionsFetchDone(KJob *job)
@@ -381,7 +363,7 @@ void MessageActions::slotUpdateActionsFetchDone(KJob *job)
     if (fetchJob->items().isEmpty()) {
         return;
     }
-    Akonadi::Item messageItem = fetchJob->items().first();
+    const Akonadi::Item messageItem = fetchJob->items().constFirst();
     if (messageItem == mCurrentItem) {
         mCurrentItem = messageItem;
         updateMailingListActions(messageItem);
@@ -429,7 +411,7 @@ void MessageActions::updateMailingListActions(const Akonadi::Item &messageItem)
         qDeleteAll(mMailListActionList);
         mMailListActionList.clear();
         if (!listId.isEmpty()) {
-            mMailingListActionMenu->menu()->setTitle(listId);
+            mMailingListActionMenu->menu()->setTitle(i18n("Mailing List Name: %1", listId));
         }
         if (mailList.features() & MessageCore::MailingList::ArchivedAt) {
             // IDEA: this may be something you want to copy - "Copy in submenu"?
@@ -679,9 +661,9 @@ void MessageActions::addWebShortcutsMenu(QMenu *menu, const QString &text)
     mWebShortcutMenuManager->addWebShortcutsToMenu(menu);
 }
 
-QAction *MessageActions::debugBalooAction() const
+QAction *MessageActions::debugAkonadiSearchAction() const
 {
-    return mDebugBalooAction;
+    return mDebugAkonadiSearchAction;
 }
 
 QAction *MessageActions::addFollowupReminderAction() const
@@ -689,7 +671,7 @@ QAction *MessageActions::addFollowupReminderAction() const
     return mAddFollowupReminderAction;
 }
 
-void MessageActions::slotDebugBaloo()
+void MessageActions::slotDebugAkonadiSearch()
 {
     if (!mCurrentItem.isValid()) {
         return;
