@@ -18,31 +18,11 @@
 */
 
 #include "kmailplugininterface.h"
-#include <KActionCollection>
 #include <kmmainwidget.h>
 #include "kmail_debug.h"
 
-class KMailPluginInterfacePrivate
-{
-public:
-    KMailPluginInterfacePrivate()
-        : kmailPluginInterface(new KMailPluginInterface)
-    {
-    }
-
-    ~KMailPluginInterfacePrivate()
-    {
-        delete kmailPluginInterface;
-    }
-
-    KMailPluginInterface *kmailPluginInterface;
-};
-
-Q_GLOBAL_STATIC(KMailPluginInterfacePrivate, sInstance)
-
 KMailPluginInterface::KMailPluginInterface(QObject *parent)
     : PimCommon::PluginInterface(parent)
-    , mMainWindow(nullptr)
 {
     setPluginName(QStringLiteral("kmail"));
     setServiceTypeName(QStringLiteral("KMail/MainViewPlugin"));
@@ -54,7 +34,8 @@ KMailPluginInterface::~KMailPluginInterface()
 
 KMailPluginInterface *KMailPluginInterface::self()
 {
-    return sInstance->kmailPluginInterface;
+    static KMailPluginInterface s_self;
+    return &s_self;
 }
 
 void KMailPluginInterface::setMainWidget(KMMainWidget *mainwindow)
