@@ -20,8 +20,7 @@
 
 #include <MailCommon/SearchPatternEdit>
 
-namespace KMail
-{
+namespace KMail {
 class KMailSearchPatternEdit : public MailCommon::SearchPatternEdit
 {
     Q_OBJECT
