@@ -100,7 +100,7 @@ Q_SIGNALS:
        */
     void tagMoreActionClicked();
 
-private Q_SLOTS:
+private:
     void finishedTagListing(KJob *job);
     void newTagActionClicked();
     void onSignalMapped(const QString &tag);
@@ -108,22 +108,21 @@ private Q_SLOTS:
     void onTagRemoved(const Akonadi::Tag &);
     void onTagChanged(const Akonadi::Tag &);
 
-private:
     void fillTagList();
     void createTagAction(const MailCommon::Tag::Ptr &tag, bool addToMenu);
     void createTagActions(const QList<MailCommon::Tag::Ptr> &);
     void checkTags(const QList<qint64> &tags);
     QList<qint64> checkedTags() const;
 
-    KActionCollection *mActionCollection;
-    MessageActions *mMessageActions;
-    QSignalMapper *mMessageTagToggleMapper;
-    KXMLGUIClient *mGUIClient;
+    KActionCollection *mActionCollection = nullptr;
+    MessageActions *mMessageActions = nullptr;
+    QSignalMapper *mMessageTagToggleMapper = nullptr;
+    KXMLGUIClient *mGUIClient = nullptr;
 
-    QAction *mSeparatorMoreAction;
-    QAction *mSeparatorNewTagAction;
-    QAction *mMoreAction;
-    QAction *mNewTagAction;
+    QAction *mSeparatorMoreAction = nullptr;
+    QAction *mSeparatorNewTagAction = nullptr;
+    QAction *mMoreAction = nullptr;
+    QAction *mNewTagAction = nullptr;
     // Maps the id of a tag to the action of a tag.
     // Contains all existing tags
     QMap<qint64, KToggleAction *> mTagActions;
@@ -135,9 +134,9 @@ private:
     QList<MailCommon::Tag::Ptr> mTags;
 
     // Uri of a newly created tag
-    qint64 mNewTagId;
-    bool mTagFetchInProgress;
-    Akonadi::Monitor *mMonitor;
+    qint64 mNewTagId = -1;
+    bool mTagFetchInProgress = false;
+    Akonadi::Monitor *mMonitor = nullptr;
 };
 }
 
