@@ -30,8 +30,8 @@ public:
     explicit CollectionPane(bool restoreSession, QAbstractItemModel *model, QItemSelectionModel *selectionModel, QWidget *parent = nullptr);
     ~CollectionPane();
 
-    MessageList::StorageModel *createStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent) Q_DECL_OVERRIDE;
-    void writeConfig(bool restoreSession) Q_DECL_OVERRIDE;
+    MessageList::StorageModel *createStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent) override;
+    void writeConfig(bool restoreSession) override;
 };
 
 class CollectionStorageModel : public MessageList::StorageModel
@@ -43,8 +43,7 @@ public:
     */
     explicit CollectionStorageModel(QAbstractItemModel *model, QItemSelectionModel *selectionModel, QObject *parent = nullptr);
     ~CollectionStorageModel();
-    bool isOutBoundFolder(const Akonadi::Collection &c) const Q_DECL_OVERRIDE;
+    bool isOutBoundFolder(const Akonadi::Collection &c) const override;
 };
 
 #endif /* COLLECTIONPANE_H */
-
