@@ -35,12 +35,12 @@ public:
 Q_SIGNALS:
     void transportSelected(MailTransport::Transport *transport);
 
-private Q_SLOTS:
+private:
     void updateTransportMenu();
     void slotCheckTransportMenu();
     void slotSelectTransport(QAction *act);
-private:
-    bool mInitialized;
+
+    bool mInitialized = false;
 };
 
 #endif // KACTIONMENUTRANSPORT_H
